@@ -1,6 +1,6 @@
 /* strptime.h
  *
- * $Id: strptime.h 11964 2005-11-17 05:35:02Z hampton $
+ * $Id: strptime.h 16073 2007-05-12 16:50:49Z andi5 $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -30,5 +30,9 @@
  */
 extern char *strptime(const char *, const char *, struct tm *);
 
+#if defined(OS_WIN32) || defined(G_OS_WIN32)
+extern char *get_win32_locale_string(int lctype);
+extern char *translate_win32_picture(const char *);
 #endif
 
+#endif
