@@ -50,6 +50,8 @@ See \ref gncnumericexample
 #ifndef GNC_NUMERIC_H
 #define GNC_NUMERIC_H
 
+#include <glib-object.h>
+
 struct _gnc_numeric 
 {
   gint64  num;
@@ -445,6 +447,14 @@ gnc_numeric gnc_numeric_convert_with_error(gnc_numeric in, gint64 denom,
 gnc_numeric gnc_numeric_reduce(gnc_numeric in);
 /** @} */
 
+/** @name GValue 
+  @{
+*/
+GType gnc_numeric_get_type( void );
+#define GNC_TYPE_NUMERIC (gnc_numeric_get_type ())
+
+/** @} */
+
 /** @name Deprecated, backwards-compatible definitions 
   @{
 */
