@@ -144,7 +144,7 @@ function inst_mingw() {
             wget_unpacked $MINGW_RT_URL $DOWNLOAD_DIR $MINGW_DIR
             wget_unpacked $W32API_URL $DOWNLOAD_DIR $MINGW_DIR
             wget_unpacked $MINGW_MAKE_URL $DOWNLOAD_DIR $MINGW_DIR
-            (echo "y"; echo "y"; echo "$_MINGW_WFSDIR") | sh pi.sh
+            (echo "y"; echo "y"; echo "$_MINGW_WFSDIR"; echo "y") | sh pi.sh
         else
             ./create_cross_mingw.sh
         fi
@@ -472,13 +472,15 @@ function inst_gnome() {
         mkdir -p $_GNOME_UDIR
         wget_unpacked $LIBXML2_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $LIBXML2_DEV_URL $DOWNLOAD_DIR $GNOME_DIR
-        wget_unpacked $GETTEXT_URL $DOWNLOAD_DIR $GNOME_DIR
-        wget_unpacked $GETTEXT_DEV_URL $DOWNLOAD_DIR $GNOME_DIR
+        wget_unpacked $GETTEXT_RUNTIME_URL $DOWNLOAD_DIR $GNOME_DIR
+        wget_unpacked $GETTEXT_RUNTIME_DEV_URL $DOWNLOAD_DIR $GNOME_DIR
+        wget_unpacked $GETTEXT_TOOLS_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $LIBICONV_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $GLIB_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $GLIB_DEV_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $LIBJPEG_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $LIBPNG_URL $DOWNLOAD_DIR $GNOME_DIR
+        wget_unpacked $LIBTIFF_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $ZLIB_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $PKG_CONFIG_URL $DOWNLOAD_DIR $GNOME_DIR
         wget_unpacked $CAIRO_URL $DOWNLOAD_DIR $GNOME_DIR
@@ -841,7 +843,8 @@ function inst_ktoblzcheck() {
             # circumvent binreloc bug, http://trac.autopackage.org/ticket/28
             ./configure ${HOST_XCOMPILE} \
                 --prefix=${_GWENHYWFAR_UDIR} \
-                --disable-binreloc
+                --disable-binreloc \
+                --disable-python
             make
             [ "$CROSS_COMPILE" != "yes" ] && make check
             make install
@@ -1012,6 +1015,10 @@ function inst_gnucash() {
         for A in *.la; do
             sed '/dependency_libs/d' $A > tmp ; mv tmp $A
         done
+
+        # gettext 0.17 installs translations to \share\locale, but not all
+        # gnome packages have been recompiled against it
+        cp -a locale ../share && rm -rf locale
     qpopd
 
     qpushd $_INSTALL_UDIR/etc/gconf/schemas
@@ -1025,12 +1032,13 @@ function inst_gnucash() {
 
     # Create a startup script that works without the msys shell
     qpushd $_INSTALL_UDIR/bin
-        echo "set PATH=${INSTALL_DIR}\\bin;${INSTALL_DIR}\\lib;${INSTALL_DIR}\\lib\\gnucash;${GOFFICE_DIR}\\bin;${LIBGSF_DIR}\\bin;${PCRE_DIR}\\bin;${GNOME_DIR}\\bin;${LIBXML2_DIR}\\bin;${GUILE_DIR}\\bin;${REGEX_DIR}\\bin;${AUTOTOOLS_DIR}\\bin;${AQBANKING_PATH};${LIBOFX_DIR}\\bin;${OPENSP_DIR}\\bin;%PATH%" > gnucash.bat
+        echo "setlocal" > gnucash.bat
+        echo "set PATH=${INSTALL_DIR}\\bin;${INSTALL_DIR}\\lib;${INSTALL_DIR}\\lib\\gnucash;${GOFFICE_DIR}\\bin;${LIBGSF_DIR}\\bin;${PCRE_DIR}\\bin;${GNOME_DIR}\\bin;${LIBXML2_DIR}\\bin;${GUILE_DIR}\\bin;${REGEX_DIR}\\bin;${AUTOTOOLS_DIR}\\bin;${AQBANKING_PATH};${LIBOFX_DIR}\\bin;${OPENSP_DIR}\\bin;%PATH%" >> gnucash.bat
         echo "set GUILE_WARN_DEPRECATED=no" >> gnucash.bat
         echo "set GNC_MODULE_PATH=${INSTALL_DIR}\\lib\\gnucash" >> gnucash.bat
         echo "set GUILE_LOAD_PATH=${INSTALL_DIR}\\share\\gnucash\\guile-modules;${INSTALL_DIR}\\share\\gnucash\\scm;%GUILE_LOAD_PATH%" >> gnucash.bat
         echo "set LTDL_LIBRARY_PATH=${INSTALL_DIR}\\lib" >> gnucash.bat
-        echo "start gnucash-bin" >> gnucash.bat
+        echo "start gnucash-bin %*" >> gnucash.bat
     qpopd
 }
 
@@ -1067,6 +1075,8 @@ function inst_docs() {
     _DOCS_UDIR=`unix_path $DOCS_DIR`
     if [ ! -d $_DOCS_UDIR/docbook-xsl ] ; then
         wget_unpacked $DOCBOOK_XSL_URL $DOWNLOAD_DIR $DOCS_DIR
+        # add a pause to allow windows to realize that the files now exist
+        sleep 1
         mv $_DOCS_UDIR/docbook-xsl-* $_DOCS_UDIR/docbook-xsl
     fi
     mkdir -p $_DOCS_UDIR/repos
