@@ -23,13 +23,21 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <string.h>
-#include <g-wrap-wct.h>
+#include "swig-runtime.h"
 #include <libguile.h>
+#include <errno.h>
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+#ifndef HAVE_STRPTIME
+#    include "strptime.h"
+#endif
 
 #include "qof.h"
 #include "engine-helpers.h"
 #include "glib-helpers.h"
 #include "gnc-gconf-utils.h"
+#include "gnc-glib-utils.h"
 #include "guile-util.h"
 #include "guile-mappings.h"
 
@@ -74,6 +82,16 @@ struct _predicates
   SCM is_trans_scm;
 } predicates;
 
+struct _Process
+{
+  GPid pid;
+  gint fd_stdin;
+  gint fd_stdout;
+  gint fd_stderr;
+  gboolean dead;
+  gboolean detached;
+};
+
 
 static void
 initialize_scm_functions()
@@ -367,7 +385,7 @@ gnc_scm_lookup(const char *module, const char *symbol)
 SCM
 gnc_copy_split(Split *split, gboolean use_cut_semantics)
 {
-  static SCM split_type = SCM_UNDEFINED;
+  static swig_type_info *split_type = NULL;
   SCM func;
   SCM arg;
 
@@ -378,13 +396,10 @@ gnc_copy_split(Split *split, gboolean use_cut_semantics)
   if (!SCM_PROCEDUREP(func))
     return SCM_UNDEFINED;
 
-  if(split_type == SCM_UNDEFINED) {
-    split_type = scm_c_eval_string("<gnc:Split*>");
-    /* don't really need this - types are bound globally anyway. */
-    if(split_type != SCM_UNDEFINED) scm_gc_protect_object(split_type);
-  }
+  if (!split_type)
+      split_type = SWIG_TypeQuery("_p_Split");
 
-  arg = gw_wcp_assimilate_ptr(split, split_type);
+  arg = SWIG_NewPointerObj(split, split_type, 0);
 
   return scm_call_2(func, arg, SCM_BOOL(use_cut_semantics));
 }
@@ -402,7 +417,7 @@ void
 gnc_copy_split_scm_onto_split(SCM split_scm, Split *split,
                               QofBook * book)
 {
-  static SCM split_type = SCM_UNDEFINED;
+  static swig_type_info *split_type = NULL;
   SCM result;
   SCM func;
   SCM arg;
@@ -427,13 +442,10 @@ gnc_copy_split_scm_onto_split(SCM split_scm, Split *split,
   if (!SCM_PROCEDUREP(func))
     return;
 
-  if(split_type == SCM_UNDEFINED) {
-    split_type = scm_c_eval_string("<gnc:Split*>");
-    /* don't really need this - types are bound globally anyway. */
-    if(split_type != SCM_UNDEFINED) scm_gc_protect_object(split_type);
-  }
+  if (!split_type)
+      split_type = SWIG_TypeQuery("_p_Split");
 
-  arg = gw_wcp_assimilate_ptr(split, split_type);
+  arg = SWIG_NewPointerObj(split, split_type, 0);
 
   scm_call_3(func, split_scm, arg, gnc_book_to_scm (book));
 }
@@ -736,7 +748,7 @@ gnc_split_scm_get_value(SCM split_scm)
 SCM
 gnc_copy_trans(Transaction *trans, gboolean use_cut_semantics)
 {
-  static SCM trans_type = SCM_UNDEFINED;
+  static swig_type_info *trans_type = NULL;
   SCM func;
   SCM arg;
 
@@ -747,13 +759,10 @@ gnc_copy_trans(Transaction *trans, gboolean use_cut_semantics)
   if (!SCM_PROCEDUREP(func))
     return SCM_UNDEFINED;
 
-  if(trans_type == SCM_UNDEFINED) {
-    trans_type = scm_c_eval_string("<gnc:Transaction*>");
-    /* don't really need this - types are bound globally anyway. */
-    if(trans_type != SCM_UNDEFINED) scm_gc_protect_object(trans_type);
-  }
+  if (!trans_type)
+      trans_type = SWIG_TypeQuery("_p_Transaction");
 
-  arg = gw_wcp_assimilate_ptr(trans, trans_type);
+  arg = SWIG_NewPointerObj(trans, trans_type, 0);
 
   return scm_call_2(func, arg, SCM_BOOL(use_cut_semantics));
 }
@@ -798,7 +807,7 @@ gnc_copy_trans_scm_onto_trans_swap_accounts(SCM trans_scm,
                                             gboolean do_commit,
                                             QofBook *book)
 {
-  static SCM trans_type = SCM_UNDEFINED;
+  static swig_type_info *trans_type = NULL;
   SCM result;
   SCM func;
   SCM arg;
@@ -823,13 +832,10 @@ gnc_copy_trans_scm_onto_trans_swap_accounts(SCM trans_scm,
   if (!SCM_PROCEDUREP(func))
     return;
 
-  if(trans_type == SCM_UNDEFINED) {
-    trans_type = scm_c_eval_string("<gnc:Transaction*>");
-    /* don't really need this - types are bound globally anyway. */
-    if(trans_type != SCM_UNDEFINED) scm_gc_protect_object(trans_type);
-  }
+  if (!trans_type)
+      trans_type = SWIG_TypeQuery("_p_Transaction");
 
-  arg = gw_wcp_assimilate_ptr(trans, trans_type);
+  arg = SWIG_NewPointerObj(trans, trans_type, 0);
 
   if ((guid_1 == NULL) || (guid_2 == NULL))
   {
@@ -1088,7 +1094,6 @@ gnc_trans_scm_get_num_splits(SCM trans_scm)
 char *
 gnc_get_debit_string(GNCAccountType account_type)
 {
-  const char *type_string;
   const gchar *string;
   SCM result;
   SCM arg;
@@ -1098,12 +1103,10 @@ gnc_get_debit_string(GNCAccountType account_type)
   if (gnc_gconf_get_bool(GCONF_GENERAL, KEY_ACCOUNTING_LABELS, NULL))
     return g_strdup(_("Debit"));
 
-  if ((account_type < NO_TYPE) || (account_type >= NUM_ACCOUNT_TYPES))
-    account_type = NO_TYPE;
+  if ((account_type < ACCT_TYPE_NONE) || (account_type >= NUM_ACCOUNT_TYPES))
+    account_type = ACCT_TYPE_NONE;
 
-  type_string = xaccAccountTypeEnumAsString(account_type);
-
-  arg = scm_str2symbol(type_string);
+  arg = scm_long2num(account_type);
 
   result = scm_call_1(getters.debit_string, arg);
   if (!SCM_STRINGP(result))
@@ -1126,7 +1129,6 @@ gnc_get_debit_string(GNCAccountType account_type)
 char *
 gnc_get_credit_string(GNCAccountType account_type)
 {
-  const char *type_string;
   const gchar *string;
   SCM result;
   SCM arg;
@@ -1136,12 +1138,10 @@ gnc_get_credit_string(GNCAccountType account_type)
   if (gnc_gconf_get_bool(GCONF_GENERAL, KEY_ACCOUNTING_LABELS, NULL))
     return g_strdup(_("Credit"));
 
-  if ((account_type < NO_TYPE) || (account_type >= NUM_ACCOUNT_TYPES))
-    account_type = NO_TYPE;
+  if ((account_type < ACCT_TYPE_NONE) || (account_type >= NUM_ACCOUNT_TYPES))
+    account_type = ACCT_TYPE_NONE;
 
-  type_string = xaccAccountTypeEnumAsString(account_type);
-
-  arg = scm_str2symbol(type_string);
+  arg = scm_long2num(account_type);
 
   result = scm_call_1(getters.credit_string, arg);
   if (!SCM_STRINGP(result))
@@ -1176,3 +1176,136 @@ gchar *gnc_guile_strip_comments (const gchar *raw_text)
   g_strfreev(splits);
   return text;
 }
+
+
+static void
+on_child_exit (GPid pid, gint status, gpointer data)
+{
+  Process *proc = data;
+  g_return_if_fail (proc && proc->pid == pid);
+
+  g_spawn_close_pid (proc->pid);
+
+  /* free if the process is both dead and detached */
+  if (!proc->detached)
+    proc->dead = TRUE;
+  else
+    g_free (proc);
+}
+
+Process *
+gnc_spawn_process_async (GList *argl, const gboolean search_path)
+{
+  gboolean retval;
+  Process *proc;
+  GList *l_iter;
+  guint argc;
+  gchar **argv, **v_iter;
+  GSpawnFlags flags;
+  GError *error = NULL;
+
+  proc = g_new0 (Process, 1);
+
+  argc = g_list_length (argl);
+  argv = g_malloc ((argc+1) * sizeof(gchar*));
+
+  for (l_iter=argl, v_iter=argv; l_iter; l_iter=l_iter->next, v_iter++) {
+    *v_iter = (gchar*) l_iter->data;
+  }
+  *v_iter = NULL;
+  g_list_free (argl);
+
+  flags = G_SPAWN_DO_NOT_REAP_CHILD;
+  if (search_path)
+    flags |= G_SPAWN_SEARCH_PATH;
+
+  retval = g_spawn_async_with_pipes (
+    NULL, argv, NULL, flags, NULL, NULL, &proc->pid,
+    &proc->fd_stdin, &proc->fd_stdout, &proc->fd_stderr, &error);
+
+  if (retval) {
+    g_child_watch_add (proc->pid, on_child_exit, proc);
+  } else {
+    g_warning ("Could not spawn %s: %s", *argv ? *argv : "(null)",
+               error->message ? error->message : "(null)");
+    g_free (proc);
+    proc = NULL;
+  }
+  g_strfreev (argv);
+
+  return proc;
+}
+
+gint
+gnc_process_get_fd (const Process *proc, const gint std_fd)
+{
+  const gint *retptr = NULL;
+  g_return_val_if_fail (proc, -1);
+
+  if (std_fd == 0)
+    retptr = &proc->fd_stdin;
+  else if (std_fd == 1)
+    retptr = &proc->fd_stdout;
+  else if (std_fd == 2)
+    retptr = &proc->fd_stderr;
+  else
+    g_return_val_if_reached (-1);
+
+  if (*retptr == -1)
+    g_warning ("Pipe to childs file descriptor %d is -1", std_fd);
+  return *retptr;
+}
+
+void
+gnc_detach_process (Process *proc, const gboolean kill_it)
+{
+  g_return_if_fail (proc && proc->pid);
+
+  errno = 0;
+  close (proc->fd_stdin);
+  if (errno) {
+    g_message ("Close of childs stdin (%d) failed: %s", proc->fd_stdin,
+	       g_strerror (errno));
+    errno = 0;
+  }
+  close (proc->fd_stdout);
+  if (errno) {
+    g_message ("Close of childs stdout (%d) failed: %s", proc->fd_stdout,
+	       g_strerror(errno));
+    errno = 0;
+  }
+  close (proc->fd_stderr);
+  if (errno) {
+    g_message ("Close of childs stderr (%d) failed: %s", proc->fd_stderr,
+	       g_strerror(errno));
+    errno = 0;
+  }
+
+  if (kill_it && !proc->dead) {
+    /* give it a chance to die */
+    while (g_main_context_iteration (NULL, FALSE) && !proc->dead)
+      ;
+    if (!proc->dead)
+      gnc_gpid_kill (proc->pid);
+  }
+
+  /* free if the process is both dead and detached */
+  if (!proc->dead)
+    proc->detached = TRUE;
+  else
+    g_free (proc);
+}
+
+
+time_t
+gnc_parse_time_to_timet(const gchar *s, const gchar *format)
+{
+  struct tm tm;
+
+  g_return_val_if_fail(s && format, -1);
+
+  if (!strptime(s, format, &tm))
+    return -1;
+
+  return mktime(&tm);
+}
