@@ -38,8 +38,6 @@
 #include <libpq-fe.h>  
 
 #include "AccountP.h"
-#include "Group.h"
-#include "GroupP.h"
 #include "gnc-commodity.h"
 #include "gnc-engine.h"
 #include "gnc-pricedb.h"
@@ -186,7 +184,7 @@ pgendSplitLookup (PGBackend *be, const GUID *split_guid)
 
 struct _iter {
   const GUID *guid;
-  QofEntity *ent;
+  QofInstance *ent;
 };
 
 static void
@@ -447,7 +445,7 @@ query_cb (PGBackend *be, PGresult *result, int j, gpointer data)
       {
          gint32 db_version, cache_version;
          db_version = atoi (DB_GET_VAL("version",j));
-         cache_version = xaccTransGetVersion (trans);
+         cache_version = qof_instance_get_version (trans);
          if (db_version <= cache_version) {
             return qd;
          }
@@ -467,8 +465,8 @@ query_cb (PGBackend *be, PGresult *result, int j, gpointer data)
    xaccTransSetDatePostedTS (trans, &ts);
    ts = gnc_iso8601_to_timespec_gmt (DB_GET_VAL("date_entered",j));
    xaccTransSetDateEnteredTS (trans, &ts);
-   xaccTransSetVersion (trans, atoi(DB_GET_VAL("version",j)));
-   trans->idata = atoi(DB_GET_VAL("iguid",j));
+   qof_instance_set_version (trans, atoi(DB_GET_VAL("version",j)));
+   qof_instance_set_idata(trans, atoi(DB_GET_VAL("iguid",j)));
 
    currency = gnc_string_to_commodity (DB_GET_VAL("currency",j), 
                                        pgendGetBook(be));
@@ -510,7 +508,7 @@ pgendFillOutToCheckpoint (PGBackend *be, const char *query_string)
    qd.resolve_list = NULL;
 
    ENTER (" ");
-   if (!be) return;
+   if (!be) { LEAVE(""); return; }
 
    if (0 == ncalls) {
       START_CLOCK (9, "starting at level 0");
@@ -566,13 +564,15 @@ pgendFillOutToCheckpoint (PGBackend *be, const char *query_string)
       Transaction *trans = (Transaction *) node->data;
       GList *engine_splits, *snode;
 
-      trans->inst.kvp_data = pgendKVPFetch (be, trans->idata, trans->inst.kvp_data);
+      trans->inst.kvp_data = pgendKVPFetch(be, qof_instance_get_idata(trans),
+                                           trans->inst.kvp_data);
    
       engine_splits = xaccTransGetSplitList(trans);
       for (snode = engine_splits; snode; snode=snode->next)
       {
          Split *s = snode->data;
-         s->inst.kvp_data = pgendKVPFetch (be, s->idata, s->inst.kvp_data);
+         s->inst.kvp_data = pgendKVPFetch(be, qof_instance_get_idata(s),
+                                          s->inst.kvp_data);
       }
 
       xaccTransCommitEdit (trans);
@@ -656,7 +656,7 @@ pgendFillOutToCheckpoint (PGBackend *be, const char *query_string)
    qd.xaction_list = NULL;
 
    REPORT_CLOCK (9, "done gathering at call %d", call_count);
-   if (NULL == acct_list) return;
+   if (NULL == acct_list) { LEAVE(""); return; }
 
    /* OK, at this point, we have a list of accounts, including the 
     * date of the earliest split in that account.  Now, we need to 
@@ -713,7 +713,7 @@ pgendRunQuery (QofBackend *bend, gpointer q_p)
    PGBackend *be = (PGBackend *)bend;
    Query *q = (Query*) q_p;
    const char * sql_query_string;
-   AccountGroup *topgroup;
+   Account *root;
    sqlQuery *sq;
 
    ENTER ("be=%p, qry=%p", be, q);
@@ -728,10 +728,10 @@ pgendRunQuery (QofBackend *bend, gpointer q_p)
    sq = sqlQuery_new();
    sql_query_string = sqlQuery_build (sq, q);
 
-   topgroup = gnc_book_get_group (pgendGetBook(be));
+   root = gnc_book_get_root_account(pgendGetBook(be));
 
    /* stage transactions, save some postgres overhead */
-   xaccGroupBeginStagedTransactionTraversals (topgroup);
+   gnc_account_tree_begin_staged_transaction_traversals (root);
 
    /* We will be doing a bulk insertion of transactions below.
     * We can gain a tremendous performance improvement,
@@ -746,17 +746,13 @@ pgendRunQuery (QofBackend *bend, gpointer q_p)
     * by not very much.
     */
    ncalls = 0;
-   xaccAccountGroupBeginEdit(topgroup);
+   xaccAccountBeginEdit(root);
    pgendFillOutToCheckpoint (be, sql_query_string);
-   xaccAccountGroupCommitEdit(topgroup);
+   xaccAccountCommitEdit(root);
    PINFO ("number of calls to fill out=%d", ncalls);
 
    sql_Query_destroy(sq);
 
-   /* the fill-out will dirty a lot of data. That's irrelevent,
-    * mark it all as having been saved. */
-   xaccGroupMarkSaved (topgroup);
-
    pgendEnable(be);
    qof_event_resume();
 
@@ -793,7 +789,7 @@ get_all_trans_cb (PGBackend *be, PGresult *result, int j, gpointer data)
 
 
 static void
-pgendGetAllTransactions (PGBackend *be, AccountGroup *grp)
+pgendGetAllTransactions (PGBackend *be, Account *root)
 {
    GList *node, *xaction_list = NULL;
 
@@ -804,14 +800,14 @@ pgendGetAllTransactions (PGBackend *be, AccountGroup *grp)
    xaction_list = pgendGetResults (be, get_all_trans_cb, xaction_list);
 
    /* restore the transactions */
-   xaccAccountGroupBeginEdit (grp);
+   xaccAccountBeginEdit (root);
    for (node=xaction_list; node; node=node->next)
    {
       xxxpgendCopyTransactionToEngine (be, (GUID *)node->data);
       guid_free (node->data);
    }
    g_list_free(xaction_list);
-   xaccAccountGroupCommitEdit (grp);
+   xaccAccountCommitEdit (root);
 
    pgendEnable(be);
    qof_event_resume();
@@ -871,9 +867,9 @@ static void
 pgendSync (QofBackend *bend, QofBook *book)
 {
    PGBackend *be = (PGBackend *)bend;
-   AccountGroup *grp = gnc_book_get_group (book);
+   Account *root = gnc_book_get_root_account(book);
 
-   ENTER ("be=%p, grp=%p", be, grp);
+   ENTER ("be=%p, root=%p", be, root);
 
    pgend_set_book (be, book);
    be->version_check = (guint32) time(0);
@@ -894,8 +890,8 @@ pgendSync (QofBackend *bend, QofBook *book)
    pgendStoreBook (be, book);
 
    /* store the account group hierarchy, and then all transactions */
-   pgendStoreGroup (be, grp);
-   pgendStoreAllTransactions (be, grp);
+   pgendStoreAccountTree (be, root);
+   pgendStoreAllTransactions (be, root);
 
    /* don't send events  to GUI, don't accept callbacks to backend */
    qof_event_suspend();
@@ -907,7 +903,7 @@ pgendSync (QofBackend *bend, QofBook *book)
        (MODE_SINGLE_UPDATE != be->session_mode))
    {
       Timespec ts = gnc_iso8601_to_timespec_gmt (CK_BEFORE_LAST_DATE);
-      pgendGroupGetAllBalances (be, grp, ts);
+      pgendAccountTreeGetAllBalances (be, root, ts);
    } 
    else
    {
@@ -958,9 +954,9 @@ pgendSyncSingleFile (QofBackend *bend, QofBook *book)
    char buff[4000];
    char *p;
    PGBackend *be = (PGBackend *)bend;
-   AccountGroup *grp = gnc_book_get_group (book);
+   Account *root = gnc_book_get_root_account(book);
 
-   ENTER ("be=%p, grp=%p", be, grp);
+   ENTER ("be=%p, root=%p", be, root);
 
    pgend_set_book (be, book);
 
@@ -1017,14 +1013,14 @@ pgendSyncSingleFile (QofBackend *bend, QofBook *book)
    pgendStoreBookNoLock (be, book, TRUE);
 
    /* Store accounts and commodities */
-   xaccClearMarkDownGr (grp, 0);
-   pgendStoreGroupNoLock (be, grp, TRUE, TRUE);
-   xaccClearMarkDownGr (grp, 0);
+   xaccClearMarkDown (root, 0);
+   pgendStoreAccountTreeNoLock (be, root, TRUE, TRUE);
+   xaccClearMarkDown (root, 0);
 
    /* Recursively walk transactions. Start by reseting the write 
     * flags. We use this to avoid infinite recursion */
-   xaccGroupBeginStagedTransactionTraversals(grp);
-   xaccGroupStagedTransactionTraversal (grp, 1, trans_traverse_cb, be);
+   gnc_account_tree_begin_staged_transaction_traversals(root);
+   gnc_account_tree_staged_transaction_traversal (root, 1, trans_traverse_cb, be);
 
    /* hack alert -- In some deranged theory, we should be
     * syncing prices here, as well as syncing any/all other
@@ -1424,7 +1420,7 @@ pgend_session_end (QofBackend *bend)
           * it might be opened in multi-user mode next time. Thus, update
           * the account balance checkpoints just in case. 
           */
-         /* pgendGroupRecomputeAllCheckpoints (be, be->topgroup); */
+         /* pgendAccountTreeRecomputeAllCheckpoints (be, be->root); */
          break;
 
       case MODE_POLL:
@@ -1481,7 +1477,7 @@ static void
 pgend_book_load_poll (QofBackend *bend, QofBook *book)
 {
    Timespec ts = gnc_iso8601_to_timespec_gmt (CK_BEFORE_LAST_DATE);
-   AccountGroup *grp;
+   Account *root;
    PGBackend *be = (PGBackend *)bend;
 
    if (!be) return;
@@ -1508,10 +1504,10 @@ pgend_book_load_poll (QofBackend *bend, QofBook *book)
 
    pgendGetAllAccountsInBook (be, book);
 
-   grp = gnc_book_get_group (book);
-   xaccAccountGroupBeginEdit (grp);
-   pgendGroupGetAllBalances (be, grp, ts);
-   xaccAccountGroupCommitEdit (grp);
+   root = gnc_book_get_root_account (book);
+   xaccAccountBeginEdit (root);
+   pgendAccountTreeGetAllBalances (be, root, ts);
+   xaccAccountCommitEdit (root);
 
    /* re-enable events */
    pgendEnable(be);
@@ -1633,7 +1629,7 @@ static void
 pgend_do_begin (QofBackend *bend, QofInstance *inst)
 {
   PGBackend *be = (PGBackend*)bend;
-  QofIdTypeConst type = inst->entity.e_type;
+  QofIdTypeConst type = inst->e_type;
 
   ENTER ("be=%p, type=%s", bend, type);
   // if (!safe_strcmp (type, GNC_ID_PERIOD))
@@ -1659,7 +1655,7 @@ static void
 pgend_do_commit (QofBackend *bend, QofInstance *inst)
 {
   PGBackend *be = (PGBackend*)bend;
-  QofIdTypeConst type = inst->entity.e_type;
+  QofIdTypeConst type = inst->e_type;
 
   ENTER ("be=%p, type=%s", bend, type);
   // if (!safe_strcmp (type, GNC_ID_PERIOD))
@@ -1695,7 +1691,7 @@ static void
 pgend_do_rollback (QofBackend *bend, QofInstance *inst)
 {
   PGBackend *be = (PGBackend*)bend;
-  QofIdTypeConst type = inst->entity.e_type;
+  QofIdTypeConst type = inst->e_type;
 
   ENTER ("be=%p, type=%s", bend, type);
   switch (be->session_mode) {
@@ -2237,8 +2233,6 @@ pgend_session_begin (QofBackend *backend,
 
    /* ---------------------------------------------------------------- */
 
-   // DEBUGCMD (PQtrace(be->connection, stderr));
-
    /* set the datestyle to something we can parse */
    p = "SET DATESTYLE='ISO';";
    SEND_QUERY (be,p, );
@@ -2542,8 +2536,8 @@ pg_provider_free (QofBackendProvider *prov)
         g_free (prov);
 }
 
-G_MODULE_EXPORT const gchar *
-g_module_check_init(GModule *module)
+G_MODULE_EXPORT void
+qof_backend_module_init(void)
 {
 	QofBackendProvider *prov;
 
@@ -2555,7 +2549,6 @@ g_module_check_init(GModule *module)
 	prov->provider_free = pg_provider_free;
 	prov->check_data_type = NULL;
 	qof_backend_register_provider (prov);
-	return NULL;
 }
 
 /* ======================== END OF FILE ======================== */
