@@ -1,7 +1,7 @@
 /*********************************************************************
  * gncmod-business-backend-file.c
  * module definition/initialization for the file backend module
- * 
+ *
  * Copyright (c) 2002 Derek Atkins <warlord@MIT.EDU>
  *
  * This program is free software; you can redistribute it and/or
@@ -23,8 +23,8 @@
  *
  *********************************************************************/
 
-#include <stdio.h>
-#include <glib.h>
+#include "config.h"
+#include <gmodule.h>
 
 #include "gnc-module.h"
 #include "gnc-module-api.h"
@@ -43,39 +43,35 @@
 #include "gnc-tax-table-xml-v2.h"
 #include "gnc-vendor-xml-v2.h"
 
+GNC_MODULE_API_DECL(libgncmod_business_backend_file)
+
 /* version of the gnc module system interface we require */
-int libgncmod_business_backend_file_LTX_gnc_module_system_interface = 0;
+int libgncmod_business_backend_file_gnc_module_system_interface = 0;
 
 /* module versioning uses libtool semantics. */
-int libgncmod_business_backend_file_LTX_gnc_module_current  = 0;
-int libgncmod_business_backend_file_LTX_gnc_module_revision = 0;
-int libgncmod_business_backend_file_LTX_gnc_module_age      = 0;
+int libgncmod_business_backend_file_gnc_module_current  = 0;
+int libgncmod_business_backend_file_gnc_module_revision = 0;
+int libgncmod_business_backend_file_gnc_module_age      = 0;
 
 static GNCModule bus_core;
 static GNCModule file;
 
-/* forward references */
-char *libgncmod_business_backend_file_LTX_gnc_module_path(void);
-char *libgncmod_business_backend_file_LTX_gnc_module_description(void);
-int libgncmod_business_backend_file_LTX_gnc_module_init(int refcount);
-int libgncmod_business_backend_file_LTX_gnc_module_end(int refcount);
-
 
 char *
-libgncmod_business_backend_file_LTX_gnc_module_path(void) 
+libgncmod_business_backend_file_gnc_module_path(void)
 {
   return g_strdup("gnucash/business-core-file");
 }
 
-char * 
-libgncmod_business_backend_file_LTX_gnc_module_description(void) 
+char *
+libgncmod_business_backend_file_gnc_module_description(void)
 {
   return g_strdup("The XML (v2) parsers for GnuCash business objects");
 }
 
 int
-libgncmod_business_backend_file_LTX_gnc_module_init(int refcount) 
-{  
+libgncmod_business_backend_file_gnc_module_init(int refcount)
+{
   if(!gnc_engine_is_initialized()) { return FALSE; }
 
   bus_core = gnc_module_load("gnucash/business-core", 0);
@@ -100,7 +96,7 @@ libgncmod_business_backend_file_LTX_gnc_module_init(int refcount)
 }
 
 int
-libgncmod_business_backend_file_LTX_gnc_module_end(int refcount) 
+libgncmod_business_backend_file_gnc_module_end(int refcount)
 {
   int unload = TRUE;
 
