@@ -55,6 +55,7 @@ taxincluded, active and jobs are identical to ::GncVendor.
 
 */
 typedef struct _gncCustomer GncCustomer;
+typedef struct _gncCustomerClass GncCustomerClass;
 
 #include "gncAddress.h"
 #include "gncBillTerm.h"
@@ -62,8 +63,20 @@ typedef struct _gncCustomer GncCustomer;
 #include "gncJob.h"
 
 #define GNC_ID_CUSTOMER       "gncCustomer"
-#define GNC_IS_CUSTOMER(obj)  (QOF_CHECK_TYPE((obj), GNC_ID_CUSTOMER))
-#define GNC_CUSTOMER(obj)     (QOF_CHECK_CAST((obj), GNC_ID_CUSTOMER, GncCustomer))
+
+/* --- type macros --- */
+#define GNC_TYPE_CUSTOMER            (gnc_customer_get_type ())
+#define GNC_CUSTOMER(o)              \
+     (G_TYPE_CHECK_INSTANCE_CAST ((o), GNC_TYPE_CUSTOMER, GncCustomer))
+#define GNC_CUSTOMER_CLASS(k)        \
+     (G_TYPE_CHECK_CLASS_CAST((k), GNC_TYPE_CUSTOMER, GncCustomerClass))
+#define GNC_IS_CUSTOMER(o)           \
+     (G_TYPE_CHECK_INSTANCE_TYPE ((o), GNC_TYPE_CUSTOMER))
+#define GNC_IS_CUSTOMER_CLASS(k)     \
+     (G_TYPE_CHECK_CLASS_TYPE ((k), GNC_TYPE_CUSTOMER))
+#define GNC_CUSTOMER_GET_CLASS(o)    \
+     (G_TYPE_INSTANCE_GET_CLASS ((o), GNC_TYPE_CUSTOMER, GncCustomerClass))
+GType gnc_customer_get_type(void);
 
 /** @name Create/Destroy Functions 
  @{ */
@@ -120,7 +133,6 @@ gnc_commodity * gncCustomerGetCurrency (GncCustomer *customer);
 gboolean gncCustomerGetTaxTableOverride (GncCustomer *customer);
 GncTaxTable* gncCustomerGetTaxTable (GncCustomer *customer);
 
-KvpFrame *gncCustomerGetSlots (GncCustomer *customer);
 GList * gncCustomerGetJoblist (GncCustomer *customer, gboolean show_all);
 /** @} */
 
