@@ -33,7 +33,7 @@
 #ifndef GNC_OWNER_H_
 #define GNC_OWNER_H_
 
-typedef struct gnc_owner_s GncOwner;
+typedef struct _gncOwner GncOwner;
 
 #define GNC_ID_OWNER   "gncOwner"
 
@@ -63,21 +63,19 @@ to QOF as they can be used by objects like GncInvoice.
 /** return the type for the collection. */
 QofIdType qofOwnerGetType(GncOwner *owner);
 /** return the owner itself as an entity. */
-QofEntity* qofOwnerGetOwner (GncOwner *owner);
+QofInstance* qofOwnerGetOwner (GncOwner *owner);
 /** set the owner from the entity. */
-void qofOwnerSetEntity (GncOwner *owner, QofEntity *ent);
-
-/** \brief Set the parent owner. */
-void qofOwnerSetEndOwner (GncOwner *owner, GncOwner *parent);
-GncOwner* qofOwnerCreate (QofBook *book);
+void qofOwnerSetEntity (GncOwner *owner, QofInstance *ent);
 
 gboolean
 gncOwnerRegister(void);
 
 /** @} */
 
+#ifndef SWIG
+
 /** \struct GncOwner */
-struct gnc_owner_s {
+struct _gncOwner {
   GncOwnerType     type;      /**< Customer, Job, Vendor, Employee or Undefined. */
   union {
     gpointer       undefined;
@@ -89,6 +87,8 @@ struct gnc_owner_s {
   gpointer         qof_temp; /**< Set type independently of the owner. */
 };
 
+#endif /* SWIG */
+
 /** \name Setup routines
 @{
 */
