@@ -28,6 +28,7 @@
 #include "gnc-ui-util.h"
 #include "gnc-component-manager.h"
 #include "gnc-event.h"
+#include "gnc-gconf-utils.h"
 
 #include "gncEntry.h"
 #include "gncEntryLedger.h"
@@ -70,6 +71,20 @@ gnc_entry_ledger_refresh_internal (GncEntryLedger *ledger, GList *entries)
   ledger->loading = FALSE;
 }
 
+static void
+gnc_entry_ledger_gconf_changed (GConfEntry *entry, gpointer user_data)
+{
+  GncEntryLedger *ledger = user_data;
+
+  g_return_if_fail (ledger && entry && entry->key);
+
+  if (g_str_has_suffix (entry->key, KEY_ACCOUNT_SEPARATOR)) {
+    gnc_entry_ledger_display_refresh (ledger);
+  } else {
+    g_warning ("gnc_entry_gconf_changed: Unknown gconf key %s", entry->key);
+  }
+}
+
 static void
 gnc_entry_ledger_set_watches (GncEntryLedger *ledger, GList *entries)
 {
@@ -155,6 +170,9 @@ gnc_entry_ledger_display_init (GncEntryLedger *ledger)
   ledger->component_id = gnc_register_gui_component (ENTRYLEDGER_CLASS,
 						     refresh_handler,
 						     NULL, ledger);
+  gnc_gconf_general_register_cb(KEY_ACCOUNT_SEPARATOR,
+				gnc_entry_ledger_gconf_changed, ledger);
+
   gnc_entry_ledger_display_refresh (ledger);
 }
 
@@ -164,6 +182,8 @@ gnc_entry_ledger_display_fini (GncEntryLedger *ledger)
   if (!ledger) return;
 
   gnc_unregister_gui_component (ledger->component_id);
+  gnc_gconf_general_remove_cb(KEY_ACCOUNT_SEPARATOR,
+			      gnc_entry_ledger_gconf_changed, ledger);
 }
 
 void
