@@ -132,14 +132,15 @@ skip_expense_acct_cb (Account *account, gpointer user_data)
 
   /* Don't add A/R, A/P, Bank, Cash, or Equity accounts */
   type = xaccAccountGetType (account);
-  if (type == PAYABLE || type == RECEIVABLE ||
-      type == CASH || type == BANK || type == EQUITY)
+  if (type == ACCT_TYPE_PAYABLE || type == ACCT_TYPE_RECEIVABLE ||
+      type == ACCT_TYPE_CASH || type == ACCT_TYPE_BANK ||
+      type == ACCT_TYPE_EQUITY)
   {
     return TRUE;
   }
 
   /* If this is an ORDER or INVOICE, then leave out the expenses.  */
-  if (type == EXPENSE) return TRUE;
+  if (type == ACCT_TYPE_EXPENSE) return TRUE;
 
   /* Don't add placeholder accounts */
   if (xaccAccountGetPlaceholder (account)) return TRUE;
@@ -154,14 +155,15 @@ skip_income_acct_cb (Account *account, gpointer user_data)
 
   /* Don't add A/R, A/P, Bank, Cash, or Equity accounts */
   type = xaccAccountGetType (account);
-  if (type == PAYABLE || type == RECEIVABLE ||
-      type == CASH || type == BANK || type == EQUITY)
+  if (type == ACCT_TYPE_PAYABLE || type == ACCT_TYPE_RECEIVABLE ||
+      type == ACCT_TYPE_CASH || type == ACCT_TYPE_BANK ||
+      type == ACCT_TYPE_EQUITY)
   {
     return TRUE;
   }
 
   /* If this is a BILL, then leave out the incomes */
-  if (type == INCOME) return TRUE;
+  if (type == ACCT_TYPE_INCOME) return TRUE;
 
   /* Don't add placeholder accounts */
   if (xaccAccountGetPlaceholder (account)) return TRUE;
@@ -178,13 +180,13 @@ skip_income_acct_cb (Account *account, gpointer user_data)
 static void 
 load_xfer_type_cells (GncEntryLedger *ledger)
 {
-  AccountGroup *group;
+  Account *root;
   ComboCell *cell;
   QuickFill *qf=NULL;
   GtkListStore *store = NULL;
 
-  group = gnc_book_get_group (ledger->book);
-  if (group == NULL) return;
+  root = gnc_book_get_root_account (ledger->book);
+  if (root == NULL) return;
 
   /* Use a common, shared quickfill.  For the ORDER or INVOICE, 
    * ledgers, we don't want expense-type accounts in the menu.
@@ -196,9 +198,9 @@ load_xfer_type_cells (GncEntryLedger *ledger)
     case GNCENTRY_ORDER_VIEWER:
     case GNCENTRY_INVOICE_ENTRY:
     case GNCENTRY_INVOICE_VIEWER:
-      qf = gnc_get_shared_account_name_quickfill (group, IKEY, 
+      qf = gnc_get_shared_account_name_quickfill (root, IKEY, 
                                       skip_expense_acct_cb, NULL);
-      store = gnc_get_shared_account_name_list_store (group, IKEY,
+      store = gnc_get_shared_account_name_list_store (root, IKEY,
 						      skip_expense_acct_cb, NULL);
       break;
 
@@ -207,9 +209,9 @@ load_xfer_type_cells (GncEntryLedger *ledger)
     case GNCENTRY_EXPVOUCHER_ENTRY:
     case GNCENTRY_EXPVOUCHER_VIEWER:
     case GNCENTRY_NUM_REGISTER_TYPES:
-      qf = gnc_get_shared_account_name_quickfill (group, EKEY, 
+      qf = gnc_get_shared_account_name_quickfill (root, EKEY, 
                                       skip_income_acct_cb, NULL);
-      store = gnc_get_shared_account_name_list_store (group, EKEY,
+      store = gnc_get_shared_account_name_list_store (root, EKEY,
 						      skip_income_acct_cb, NULL);
       break;
   }
@@ -274,8 +276,6 @@ void gnc_entry_ledger_load_xfer_cells (GncEntryLedger *ledger)
  */
 void gnc_entry_ledger_load (GncEntryLedger *ledger, GList *entry_list)
 {
-  static SCM id_book = SCM_UNDEFINED;
-
   GncEntry *blank_entry, *find_entry;
   CursorBuffer *cursor_buffer;
   Table *table;
@@ -357,11 +357,8 @@ void gnc_entry_ledger_load (GncEntryLedger *ledger, GList *entry_list)
 	  break;
 	}
 
-	if (id_book == SCM_UNDEFINED)
-	  id_book = scm_c_eval_string ("gnc:id-book");
-
 	/* Compute the proper taxtable */
-	odb = gnc_option_db_new_for_type (id_book);
+	odb = gnc_option_db_new_for_type (GNC_ID_BOOK);
 	gnc_option_db_load_from_kvp (odb, gnc_book_get_slots (ledger->book));
 
 	switch (gncOwnerGetType (owner)) {
