@@ -11,7 +11,10 @@
 
 (re-export gnc-is-debugging)
 (re-export g-find-program-in-path)
+(re-export gnc-utf8?)
 (re-export gnc-utf8-strip-invalid-strdup)
+(re-export gnc-locale-from-utf8)
+(re-export gnc-locale-to-utf8)
 (re-export gnc-scm-log-warn)
 (re-export gnc-scm-log-error)
 (re-export gnc-scm-log-msg)
