@@ -33,15 +33,15 @@
  * Copyright (c) 2001-2003 Linas Vepstas <linas@linas.org>
  */
 
+#include "config.h"
 #include "AccountP.h"
 #include "qof.h"
 #include "gnc-lot.h"
 #include "gnc-lot-p.h"
 #include "gnc-pricedb.h"
 #include "gnc-pricedb-p.h"
-#include "Group.h"
-#include "GroupP.h"
 #include "Period.h"
+#include "Transaction.h"
 #include "TransactionP.h"
 
 /* This static indicates the debugging module that this .o belongs to.  */
@@ -72,7 +72,7 @@ gnc_book_insert_trans_clobber (QofBook *book, Transaction *trans)
    if (!trans || !book) return;
    
    /* If this is the same book, its a no-op. */
-   if (trans->inst.book == book) return;
+   if (qof_instance_get_book(trans) == book) return;
 
    ENTER ("trans=%p %s", trans, trans->description);
    newtrans = xaccDupeTransaction (trans);
@@ -89,8 +89,8 @@ gnc_book_insert_trans_clobber (QofBook *book, Transaction *trans)
 
    /* Fiddle the transaction into place in the new book */
    col = qof_book_get_collection (book, GNC_ID_TRANS);
-   qof_collection_insert_entity (col, &newtrans->inst.entity);
-   newtrans->inst.book = book;
+   qof_collection_insert_entity (col, &newtrans->inst);
+   qof_instance_set_book(newtrans, book);
 
    col = qof_book_get_collection (book, GNC_ID_SPLIT);
    xaccTransBeginEdit (newtrans);
@@ -100,8 +100,8 @@ gnc_book_insert_trans_clobber (QofBook *book, Transaction *trans)
       Split *s = node->data;
 
       /* move the split into the new book ... */
-      s->inst.book = book;
-      qof_collection_insert_entity(col, &s->inst.entity);
+      qof_instance_set_book(s, book);
+      qof_collection_insert_entity(col, &s->inst);
 
       /* find the twin account, and re-parent to that. */
       twin = xaccAccountLookupTwin (s->acc, book);
@@ -112,13 +112,12 @@ gnc_book_insert_trans_clobber (QofBook *book, Transaction *trans)
       else
       {
         xaccAccountInsertSplit (twin, s);
-        twin->balance_dirty = TRUE;
-        twin->sort_dirty = TRUE;
+        g_object_set(twin, "sort-dirty", TRUE, "balance-dirty", TRUE, NULL);
       }
    }
 
    xaccTransCommitEdit (newtrans);
-   qof_event_gen (&newtrans->inst.entity, QOF_EVENT_CREATE, NULL);
+   qof_event_gen (&newtrans->inst, QOF_EVENT_CREATE, NULL);
    LEAVE ("trans=%p %s", trans, trans->description);
 }
 
@@ -131,16 +130,18 @@ void
 gnc_book_insert_trans (QofBook *book, Transaction *trans)
 {
    QofCollection *col;
+   QofBook *trans_book;
    GList *node;
 
    if (!trans || !book) return;
    
    /* If this is the same book, its a no-op. */
-   if (trans->inst.book == book) return;
+   trans_book = qof_instance_get_book(trans);
+   if (trans_book == book) return;
 
    /* If the old and new book don't share backends, then clobber-copy;
     * i.e. destroy it in one backend, create it in another.  */
-   if (qof_book_get_backend(book) != qof_book_get_backend(trans->inst.book))
+   if (qof_book_get_backend(book) != qof_book_get_backend(trans_book))
    {
       gnc_book_insert_trans_clobber (book, trans);
       return;
@@ -151,8 +152,8 @@ gnc_book_insert_trans (QofBook *book, Transaction *trans)
    xaccTransBeginEdit (trans);
 
    col = qof_book_get_collection (book, GNC_ID_TRANS);
-   trans->inst.book = book;
-   qof_collection_insert_entity (col, &trans->inst.entity);
+   qof_instance_set_book(trans, book);
+   qof_collection_insert_entity (col, &trans->inst);
 
    col = qof_book_get_collection (book, GNC_ID_SPLIT);
    for (node = trans->splits; node; node = node->next)
@@ -161,10 +162,10 @@ gnc_book_insert_trans (QofBook *book, Transaction *trans)
       Split *s = node->data;
 
       /* Move the splits over (only if they haven't already been moved). */
-      if (s->inst.book != book)
+      if (qof_instance_get_book(s) != book)
       {
-         s->inst.book = book;
-         qof_collection_insert_entity (col, &s->inst.entity);
+         qof_instance_set_book(s, book);
+         qof_collection_insert_entity (col, &s->inst);
       }
 
       /* Find the twin account, and re-parent to that. */
@@ -179,14 +180,13 @@ gnc_book_insert_trans (QofBook *book, Transaction *trans)
         if (s->acc != twin)
         {
            xaccAccountInsertSplit (twin, s);
-           twin->balance_dirty = TRUE;
-           twin->sort_dirty = TRUE;
+           g_object_set(twin, "sort-dirty", TRUE, "balance-dirty", TRUE, NULL);
         }
       }
    }
 
    xaccTransCommitEdit (trans);
-   qof_event_gen (&trans->inst.entity, QOF_EVENT_MODIFY, NULL);
+   qof_event_gen (&trans->inst, QOF_EVENT_MODIFY, NULL);
    LEAVE ("trans=%p %s", trans, trans->description);
 }
 
@@ -227,18 +227,18 @@ gnc_book_insert_lot (QofBook *book, GNCLot *lot)
    ENTER ("lot=%p", lot);
 
    col = qof_book_get_collection (book, GNC_ID_LOT);
-   lot->inst.book = book;
-   qof_collection_insert_entity (col, &lot->inst.entity);
+   qof_instance_set_book(lot, book);
+   qof_collection_insert_entity (col, &lot->inst);
 
    /* Move the splits over (only if they haven't already been moved). */
    col = qof_book_get_collection (book, GNC_ID_SPLIT);
    for (snode = lot->splits; snode; snode=snode->next)
    {
       Split *s = snode->data;
-      if (s->inst.book != book)
+      if (qof_instance_get_book(s) != book)
       {
-         s->inst.book = book;
-         qof_collection_insert_entity (col, &s->inst.entity);
+         qof_instance_set_book(s, book);
+         qof_collection_insert_entity (col, &s->inst);
       }
    }
 
@@ -260,14 +260,17 @@ void
 gnc_book_insert_price (QofBook *book, GNCPrice *pr)
 {
    QofCollection *col;
+   QofBook *pr_book;
+
    if (!pr || !book) return;
    
    /* If this is the same book, its a no-op. */
-   if (pr->inst.book == book) return;
+   pr_book = qof_instance_get_book(pr);
+   if (pr_book == book) return;
 
    /* If the old and new book don't share backends, then clobber-copy;
     * i.e. destroy it in one backend, create it in another.  */
-   if (qof_book_get_backend(book) != qof_book_get_backend(pr->inst.book))
+   if (qof_book_get_backend(book) != qof_book_get_backend(pr_book))
    {
       gnc_book_insert_price_clobber (book, pr);
       return;
@@ -279,8 +282,8 @@ gnc_book_insert_price (QofBook *book, GNCPrice *pr)
    gnc_price_begin_edit (pr);
 
    col = qof_book_get_collection (book, GNC_ID_PRICE);
-   pr->inst.book = book;
-   qof_collection_insert_entity (col, &pr->inst.entity);
+   qof_instance_set_book(pr, book);
+   qof_collection_insert_entity (col, &pr->inst);
 
    gnc_pricedb_remove_price (pr->db, pr);
    gnc_pricedb_add_price (gnc_pricedb_get_db (book), pr);
@@ -395,13 +398,7 @@ lot_list_preen_open_lots (LotList *lot_list)
       LotList *lnext = lnode->next;
 
       if (lot_has_open_trans_tree (lot))
-      {
-         lot_list = g_list_remove_link (lot_list, lnode);
-         /* XXX freeing this node somehow leads to glib g_list
-          * memory corruption which later takes down the system. 
-          * I don't see why.  */
-         /* g_list_free_1 (lnode); */
-      }
+         lot_list = g_list_delete_link(lot_list, lnode);
       lnode = lnext;
    }
    LEAVE (" ");
@@ -437,29 +434,19 @@ trans_list_preen_open_lots (TransList *trans_list)
 /* clear the markers for the above routines */
 
 static void
-clear_markers (AccountGroup *grp)
+clear_markers (Account *account, gpointer dummy)
 {
-   GList *node;
+  GList *lp;
 
-   if (!grp) return;
-                                                                                
-   for (node = grp->accounts; node; node = node->next)
-   {
-      Account *account = node->data;
-      GList *lp;
-                                                                                
-      /* recursively do sub-accounts */
-      clear_markers (account->children);
-                                                                                
-      for (lp = account->splits; lp; lp = lp->next)
-      {
-        Split *s = lp->data;
-        Transaction *trans = s->parent;
-        GNCLot *lot = s->lot;
-        trans->marker = 0;
-        if (lot) lot->marker = 0;
-      }
-   }
+  if (!account) return;
+
+  for (lp = xaccAccountGetSplitList(account); lp; lp = lp->next) {
+    Split *s = lp->data;
+    Transaction *trans = s->parent;
+    GNCLot *lot = s->lot;
+    trans->marker = 0;
+    if (lot) lot->marker = 0;
+  }
 }
 
 /* ================================================================ */
@@ -531,7 +518,7 @@ void
 gnc_book_partition_txn (QofBook *dest_book, QofBook *src_book, QofQuery *query)
 {
    gnc_commodity_table *src_tbl, *dst_tbl;
-   AccountGroup *src_grp, *dst_grp;
+   Account *src_root, *dst_root;
    time_t now;
    TransList *trans_list, *tnode;
    LotList *lot_list, *lnode;
@@ -557,22 +544,18 @@ gnc_book_partition_txn (QofBook *dest_book, QofBook *src_book, QofQuery *query)
    /* hack alert -- FIXME -- this should really be a merge, not a
     * clobber copy, but I am too lazy to write an account-group merge 
     * routine, and it is not needed for the current usage. */
-   src_grp = xaccGetAccountGroup (src_book);
-   dst_grp = xaccGetAccountGroup (dest_book);
-   xaccAccountGroupBeginEdit (dst_grp);
-   xaccAccountGroupBeginEdit (src_grp);
-   xaccGroupCopyGroup (dst_grp, src_grp);
-   xaccAccountGroupCommitEdit (src_grp);
-   xaccAccountGroupCommitEdit (dst_grp);
+   src_root = gnc_book_get_root_account (src_book);
+   dst_root = gnc_book_get_root_account (dest_book);
+   gnc_account_copy_children (dst_root, src_root);
 
    /* Next, run the query */
-   xaccAccountGroupBeginEdit (dst_grp);
-   xaccAccountGroupBeginEdit (src_grp);
+   xaccAccountBeginEdit (dst_root);
+   xaccAccountBeginEdit (src_root);
    qof_query_set_book (query, src_book);
    trans_list = qof_query_run (query);
 
    /* Preen: remove open lots/ open trnasactions */
-   clear_markers (src_grp);
+   gnc_account_foreach_descendant(src_root, clear_markers, NULL);
    trans_list = trans_list_preen_open_lots (trans_list);
    lot_list = create_lot_list_from_trans_list (trans_list);
    lot_list = lot_list_preen_open_lots (lot_list);
@@ -592,8 +575,8 @@ gnc_book_partition_txn (QofBook *dest_book, QofBook *src_book, QofQuery *query)
       gnc_book_insert_trans (dest_book, trans);
    }
 
-   xaccAccountGroupCommitEdit (src_grp);
-   xaccAccountGroupCommitEdit (dst_grp);
+   xaccAccountCommitEdit (src_root);
+   xaccAccountCommitEdit (dst_root);
 
    /* Make note of the sibling books */
    now = time(0);
@@ -612,43 +595,39 @@ gnc_book_partition_txn (QofBook *dest_book, QofBook *src_book, QofQuery *query)
 static Account *
 find_nearest_equity_acct (Account *acc)
 {
-   AccountList *acc_list, *node;
-   AccountGroup *parent;
-   Account *next_up, *candidate;
+   QofBook *book;
+   GList *acc_list, *node;
+   Account *parent, *root, *candidate;
 
-   /* See if we can find an equity account that is peered to this account */
-   parent = xaccAccountGetParent (acc);
+   parent = gnc_account_get_parent (acc);
    g_return_val_if_fail (parent, NULL);
 
-   acc_list = xaccGroupGetAccountList (parent);
-   for (node=acc_list; node; node=node->next)
-   {
-      candidate = (Account *) node->data;
-      if ((EQUITY == xaccAccountGetType (candidate)) &&
-          gnc_commodity_equiv(xaccAccountGetCommodity(acc),
-                              xaccAccountGetCommodity(candidate)))
-      {
+   /* See if we can find an equity account that is peered to this
+    * account. If not, check succssively higher levels. */
+   while (parent != NULL) {
+     acc_list = gnc_account_get_children(parent);
+     for (node=acc_list; node; node=node->next) {
+       candidate = (Account *) node->data;
+       if ((ACCT_TYPE_EQUITY == xaccAccountGetType (candidate)) &&
+	   gnc_commodity_equiv(xaccAccountGetCommodity(acc),
+			       xaccAccountGetCommodity(candidate))) {
          return candidate;
-      }
+       }
+     }
+     g_list_free(acc_list);
+     parent = gnc_account_get_parent (parent);
    }
 
-   /* If we got to here, we did not find a peer equity account. 
-    * So go up one layer, and look there */
-   next_up = xaccGroupGetParentAccount (parent);
-   if (next_up) 
-   {
-      candidate = find_nearest_equity_acct (next_up);
-      if (candidate) return candidate;
-   }
-
-   /* If we got to here, then we are at the top group, and there is no 
+   /* If we got to here, then we are at the root account, and there is no 
     * equity account to be found.  So we need to create one. */
-   
-   candidate = xaccMallocAccount (xaccGroupGetBook(parent));
+
+   book = gnc_account_get_book(acc);
+   root = gnc_book_get_root_account(book);
+   candidate = xaccMallocAccount (book);
    xaccAccountBeginEdit (candidate);
-   xaccGroupInsertAccount (parent, candidate);
-   xaccAccountSetType (candidate, EQUITY);
-   xaccAccountSetName (candidate, xaccAccountGetTypeStr(EQUITY));
+   gnc_account_append_child (root, candidate);
+   xaccAccountSetType (candidate, ACCT_TYPE_EQUITY);
+   xaccAccountSetName (candidate, xaccAccountGetTypeStr(ACCT_TYPE_EQUITY));
    xaccAccountSetCommodity (candidate, xaccAccountGetCommodity(acc));
    xaccAccountCommitEdit (candidate);
    
@@ -659,28 +638,27 @@ find_nearest_equity_acct (Account *acc)
 /* Traverse all accounts, get account balances */
 
 static void
-add_closing_balances (AccountGroup *closed_grp, 
+add_closing_balances (Account *parent, 
                       QofBook *open_book,
                       QofBook *closed_book,
                       Account *equity_account,
                       Timespec *post_date, Timespec *date_entered, 
                       const char *desc)
 {
-   AccountList *acc_list, *node;
+   GList *acc_list, *node;
 
-   if (!closed_grp) return;
+   if (!parent) return;
 
    ENTER (" enter=%s post=%s desc=%s", gnc_print_date(*date_entered),
        gnc_print_date (*post_date), desc);
    xaccAccountBeginEdit (equity_account);
 
    /* Walk accounts in closed book */
-   acc_list = xaccGroupGetAccountList (closed_grp);
+   acc_list = gnc_account_get_children(parent);
    for (node=acc_list; node; node=node->next)
    {
       KvpFrame *cwd;
       Account *twin;
-      AccountGroup *childs;
       Account * candidate = (Account *) node->data;
       GNCAccountType tip = xaccAccountGetType (candidate);
 
@@ -695,7 +673,7 @@ add_closing_balances (AccountGroup *closed_grp,
       kvp_frame_set_guid (cwd, "/book/prev-acct", xaccAccountGetGUID (candidate));
       kvp_frame_set_guid (cwd, "/book/prev-book", qof_book_get_guid(closed_book));
 
-      xaccAccountSetSlots_nc (twin, twin->inst.kvp_data);
+      qof_instance_set_slots(QOF_INSTANCE(twin), twin->inst.kvp_data);
       
       /* -------------------------------- */
       /* Add KVP to closed account, indicating where 
@@ -705,12 +683,13 @@ add_closing_balances (AccountGroup *closed_grp,
       kvp_frame_set_guid (cwd, "/book/next-book", qof_book_get_guid(open_book));
       kvp_frame_set_guid (cwd, "/book/next-acct", xaccAccountGetGUID (twin));
 
-      xaccAccountSetSlots_nc (candidate, candidate->inst.kvp_data);
+      qof_instance_set_slots(QOF_INSTANCE(candidate), candidate->inst.kvp_data);
 
       /* -------------------------------- */
       /* We need to carry a balance on any account that is not
        * and income or expense or equity account */
-      if ((INCOME != tip) && (EXPENSE != tip) && (EQUITY != tip)) 
+      if ((ACCT_TYPE_INCOME != tip) && (ACCT_TYPE_EXPENSE != tip) &&
+	  (ACCT_TYPE_EQUITY != tip)) 
       {
          gnc_numeric baln;
          baln = xaccAccountGetBalance (candidate);
@@ -782,16 +761,16 @@ add_closing_balances (AccountGroup *closed_grp,
       xaccAccountCommitEdit (twin);
 
       /* Recurse down to the children */
-      childs = xaccAccountGetChildren(candidate);
-      if (childs) 
+      if (gnc_account_n_children(candidate) > 0) 
       {
          PINFO ("add closing baln to subaccts of %s", 
-                 candidate->description);
-         add_closing_balances (childs, open_book, closed_book,
+                xaccAccountGetDescription(candidate));
+         add_closing_balances (candidate, open_book, closed_book,
                           equity_account,
                           post_date, date_entered, desc);
       }
    }
+   g_list_free(acc_list);
    xaccAccountCommitEdit (equity_account);
    LEAVE (" ");
 }
@@ -892,7 +871,7 @@ gnc_book_close_period (QofBook *existing_book, Timespec calve_date,
 
    /* add in transactions to equity accounts that will
     * hold the colsing balances */
-   add_closing_balances (xaccGetAccountGroup(closing_book), 
+   add_closing_balances (gnc_book_get_root_account(closing_book), 
                         existing_book, closing_book,
                         equity_account,
                         &calve_date, &ts, memo);
