@@ -1,6 +1,6 @@
 /********************************************************************\
  * SchedXaction.c -- Scheduled Transaction implementation.          *
- * Copyright (C) 2001 Joshua Sled <jsled@asynchronous.org>          *
+ * Copyright (C) 2001,2007 Joshua Sled <jsled@asynchronous.org>     *
  *                                                                  *
  * This program is free software; you can redistribute it and/or    *
  * modify it under the terms of the GNU General Public License as   *
@@ -29,37 +29,54 @@
 
 #include "qof.h"
 
-#include "FreqSpec.h"
 #include "Account.h"
 #include "gnc-book.h"
-#include "Group.h"
-#include "GroupP.h"
 #include "SX-book.h"
 #include "SX-ttinfo.h"
 #include "SchedXaction.h"
-#include "SchedXactionP.h"
 #include "Transaction.h"
 #include "gnc-engine.h"
 
-static QofLogModule log_module = GNC_MOD_SX;
+#undef G_LOG_DOMAIN
+#define G_LOG_DOMAIN "gnc.engine.sx"
 
 /* Local Prototypes *****/
 
 void sxprivtransactionListMapDelete( gpointer data, gpointer user_data );
 
+/* GObject initialization */
+QOF_GOBJECT_IMPL(gnc_schedxaction, SchedXaction, QOF_TYPE_INSTANCE);
+
+static void
+gnc_schedxaction_init(SchedXaction* sx)
+{
+}
+
+static void
+gnc_schedxaction_dispose_real (GObject *sxp)
+{
+}
+
+static void
+gnc_schedxaction_finalize_real(GObject* sxp)
+{
+}
+
 static void
 xaccSchedXactionInit(SchedXaction *sx, QofBook *book)
 {
-   AccountGroup        *ag;
+   Account        *ra;
+   const GUID *guid;
 
-   qof_instance_init (&sx->inst, GNC_ID_SCHEDXACTION, book);
+   qof_instance_init_data (&sx->inst, GNC_ID_SCHEDXACTION, book);
 
-   sx->freq = xaccFreqSpecMalloc(book);
+   sx->schedule = NULL;
 
    g_date_clear( &sx->last_date, 1 );
    g_date_clear( &sx->start_date, 1 );
    g_date_clear( &sx->end_date, 1 );
 
+   sx->enabled = 1;
    sx->num_occurances_total = 0;
    sx->autoCreateOption = FALSE;
    sx->autoCreateNotify = FALSE;
@@ -70,17 +87,16 @@ xaccSchedXactionInit(SchedXaction *sx, QofBook *book)
 
    /* create a new template account for our splits */
    sx->template_acct = xaccMallocAccount(book);
-   /* THREAD-UNSAFE */
-   xaccAccountSetName( sx->template_acct,
-                       guid_to_string( &sx->inst.entity.guid ));
+   guid = qof_instance_get_guid( sx );
+   xaccAccountSetName( sx->template_acct, guid_to_string( guid ));
    xaccAccountSetCommodity
      (sx->template_acct,
       gnc_commodity_new( book,
-			 "template", "template",
+                         "template", "template",
                          "template", "template", 1 ) );
-   xaccAccountSetType( sx->template_acct, BANK );
-   ag = gnc_book_get_template_group( book );
-   xaccGroupInsertAccount( ag, sx->template_acct );
+   xaccAccountSetType( sx->template_acct, ACCT_TYPE_BANK );
+   ra = gnc_book_get_template_root( book );
+   gnc_account_append_child( ra, sx->template_acct );
 }
 
 SchedXaction*
@@ -90,9 +106,9 @@ xaccSchedXactionMalloc(QofBook *book)
 
    g_return_val_if_fail (book, NULL);
 
-   sx = g_new0( SchedXaction, 1 );
+   sx = g_object_new(GNC_TYPE_SCHEDXACTION, NULL);
    xaccSchedXactionInit( sx, book );
-   qof_event_gen( &sx->inst.entity, QOF_EVENT_CREATE , NULL);
+   qof_event_gen( &sx->inst, QOF_EVENT_CREATE , NULL);
 
    return sx;
 }
@@ -107,7 +123,6 @@ sxprivTransMapDelete( gpointer data, gpointer user_data )
   return;
 }
 
-
 static void
 delete_template_trans(SchedXaction *sx)
 {
@@ -138,6 +153,20 @@ delete_template_trans(SchedXaction *sx)
   
   return;
 }
+
+void
+sx_set_template_account (SchedXaction *sx, Account *account)
+{
+  Account *old;
+
+  old = sx->template_acct;
+  sx->template_acct = account;
+  if (old) {
+    xaccAccountBeginEdit(old);
+    xaccAccountDestroy(old);
+  }
+}
+
 void
 xaccSchedXactionFree( SchedXaction *sx )
 {
@@ -145,8 +174,7 @@ xaccSchedXactionFree( SchedXaction *sx )
       
   if ( sx == NULL ) return;
   
-  xaccFreqSpecFree( sx->freq );
-  qof_event_gen( &sx->inst.entity, QOF_EVENT_DESTROY , NULL);
+  qof_event_gen( &sx->inst, QOF_EVENT_DESTROY , NULL);
   
   if ( sx->name )
     g_free( sx->name );
@@ -175,8 +203,8 @@ xaccSchedXactionFree( SchedXaction *sx )
           sx->deferredList = NULL;
   }
   
-  qof_instance_release (&sx->inst);
-  g_free( sx );
+  /* qof_instance_release (&sx->inst); */
+  g_object_unref( sx );
 }
 
 /* ============================================================ */
@@ -189,40 +217,43 @@ gnc_sx_begin_edit (SchedXaction *sx)
 
 static void commit_err (QofInstance *inst, QofBackendError errcode)
 {
-  PERR ("Failed to commit: %d", errcode);
+     g_critical("Failed to commit: %d", errcode);
 }
 
-static void noop (QofInstance *inst) {}
+static void commit_done(QofInstance *inst)
+{
+  qof_event_gen (inst, QOF_EVENT_MODIFY, NULL);
+}
+
+static void noop(QofInstance *inst) {}
 
 void
 gnc_sx_commit_edit (SchedXaction *sx)
 {
   if (!qof_commit_edit (QOF_INSTANCE(sx))) return;
-  qof_commit_edit_part2 (&sx->inst, commit_err, noop, noop);
+  qof_commit_edit_part2 (&sx->inst, commit_err, commit_done, noop);
 }
 
 /* ============================================================ */
 
-FreqSpec *
-xaccSchedXactionGetFreqSpec( SchedXaction *sx )
+GList*
+gnc_sx_get_schedule(const SchedXaction *sx)
 {
-   return sx->freq;
+   return sx->schedule;
 }
 
 void
-xaccSchedXactionSetFreqSpec( SchedXaction *sx, FreqSpec *fs )
+gnc_sx_set_schedule(SchedXaction *sx, GList *schedule)
 {
-   g_return_if_fail( fs );
-
+   g_return_if_fail(sx);
    gnc_sx_begin_edit(sx);
-   xaccFreqSpecFree( sx->freq );
-   sx->freq = fs;
+   sx->schedule = schedule;
    qof_instance_set_dirty(&sx->inst);
    gnc_sx_commit_edit(sx);
 }
 
 gchar *
-xaccSchedXactionGetName( SchedXaction *sx )
+xaccSchedXactionGetName( const SchedXaction *sx )
 {
    return sx->name;
 }
@@ -257,7 +288,7 @@ xaccSchedXactionSetStartDate( SchedXaction *sx, GDate* newStart )
 }
 
 gboolean
-xaccSchedXactionHasEndDate( SchedXaction *sx )
+xaccSchedXactionHasEndDate( const SchedXaction *sx )
 {
    return g_date_valid( &sx->end_date );
 }
@@ -278,7 +309,7 @@ xaccSchedXactionSetEndDate( SchedXaction *sx, GDate *newEnd )
      * This warning is only human readable - the caller
      * doesn't know the call failed.  This is bad
      */
-    PWARN( "New end date before start date" ); 
+    g_critical("New end date before start date"); 
     return;
   }
 
@@ -295,54 +326,61 @@ xaccSchedXactionGetLastOccurDate( SchedXaction *sx )
 }
 
 void
-xaccSchedXactionSetLastOccurDate( SchedXaction *sx, GDate* newLastOccur )
+xaccSchedXactionSetLastOccurDate(SchedXaction *sx, GDate* new_last_occur)
 {
+  if (g_date_valid(&sx->last_date)
+      && g_date_compare(&sx->last_date, new_last_occur) == 0)
+    return;
   gnc_sx_begin_edit(sx);
-  sx->last_date = *newLastOccur;
+  sx->last_date = *new_last_occur;
   qof_instance_set_dirty(&sx->inst);
   gnc_sx_commit_edit(sx);
 }
 
 gboolean
-xaccSchedXactionHasOccurDef( SchedXaction *sx )
+xaccSchedXactionHasOccurDef( const SchedXaction *sx )
 {
   return ( xaccSchedXactionGetNumOccur( sx ) != 0 );
 }
 
 gint
-xaccSchedXactionGetNumOccur( SchedXaction *sx )
+xaccSchedXactionGetNumOccur( const SchedXaction *sx )
 {
   return sx->num_occurances_total;
 }
 
 void
-xaccSchedXactionSetNumOccur( SchedXaction *sx, gint newNum )
+xaccSchedXactionSetNumOccur(SchedXaction *sx, gint new_num)
 {
+  if (sx->num_occurances_total == new_num)
+    return;
   gnc_sx_begin_edit(sx);
-  sx->num_occurances_remain = sx->num_occurances_total = newNum;
+  sx->num_occurances_remain = sx->num_occurances_total = new_num;
   qof_instance_set_dirty(&sx->inst);
   gnc_sx_commit_edit(sx);
 }
 
 gint
-xaccSchedXactionGetRemOccur( SchedXaction *sx )
+xaccSchedXactionGetRemOccur( const SchedXaction *sx )
 {
   return sx->num_occurances_remain;
 }
 
 void
-xaccSchedXactionSetRemOccur( SchedXaction *sx,
-                             gint numRemain )
+xaccSchedXactionSetRemOccur(SchedXaction *sx, gint num_remain)
 {
   /* FIXME This condition can be tightened up */
-  if ( numRemain > sx->num_occurances_total ) 
+  if (num_remain > sx->num_occurances_total)
   {
-    PWARN("The number remaining is greater than the total occurrences");
+    g_warning("number remaining [%d] > total occurrences [%d]",
+              num_remain, sx->num_occurances_total);
   }
   else
   {
+    if (num_remain == sx->num_occurances_remain)
+      return;
     gnc_sx_begin_edit(sx);
-    sx->num_occurances_remain = numRemain;
+    sx->num_occurances_remain = num_remain;
     qof_instance_set_dirty(&sx->inst);
     gnc_sx_commit_edit(sx);
   }
@@ -350,7 +388,7 @@ xaccSchedXactionSetRemOccur( SchedXaction *sx,
 
 
 KvpValue *
-xaccSchedXactionGetSlot( SchedXaction *sx, const char *slot )
+xaccSchedXactionGetSlot( const SchedXaction *sx, const char *slot )
 {
   if (!sx) return NULL;
 
@@ -370,13 +408,30 @@ xaccSchedXactionSetSlot( SchedXaction *sx,
   gnc_sx_commit_edit(sx);
 }
 
+gboolean
+xaccSchedXactionGetEnabled( const SchedXaction *sx )
+{
+    return sx->enabled;
+}
+
 void
-xaccSchedXactionGetAutoCreate( SchedXaction *sx,
+xaccSchedXactionSetEnabled( SchedXaction *sx, gboolean newEnabled)
+{
+  gnc_sx_begin_edit(sx);
+  sx->enabled = newEnabled;
+  qof_instance_set_dirty(&sx->inst);
+  gnc_sx_commit_edit(sx);
+}
+
+void
+xaccSchedXactionGetAutoCreate( const SchedXaction *sx,
                                gboolean *outAutoCreate,
                                gboolean *outNotify )
 {
-  *outAutoCreate = sx->autoCreateOption;
-  *outNotify     = sx->autoCreateNotify;
+  if (outAutoCreate != NULL)
+    *outAutoCreate = sx->autoCreateOption;
+  if (outNotify != NULL)
+    *outNotify     = sx->autoCreateNotify;
   return;
 }
 
@@ -395,7 +450,7 @@ xaccSchedXactionSetAutoCreate( SchedXaction *sx,
 }
 
 gint
-xaccSchedXactionGetAdvanceCreation( SchedXaction *sx )
+xaccSchedXactionGetAdvanceCreation( const SchedXaction *sx )
 {
   return sx->advanceCreateDays;
 }
@@ -410,7 +465,7 @@ xaccSchedXactionSetAdvanceCreation( SchedXaction *sx, gint createDays )
 }
 
 gint
-xaccSchedXactionGetAdvanceReminder( SchedXaction *sx )
+xaccSchedXactionGetAdvanceReminder( const SchedXaction *sx )
 {
    return sx->advanceRemindDays;
 }
@@ -462,20 +517,20 @@ xaccSchedXactionGetNextInstance( SchedXaction *sx, void *stateData )
       }
    }
 
-   xaccFreqSpecGetNextInstance( sx->freq, &last_occur, &next_occur );
+   recurrenceListNextInstance(sx->schedule, &last_occur, &next_occur);
 
    /* out-of-bounds check */
    if ( xaccSchedXactionHasEndDate( sx ) ) {
       GDate *end_date = xaccSchedXactionGetEndDate( sx );
       if ( g_date_compare( &next_occur, end_date ) > 0 ) {
-         PINFO( "next_occur past end date" );
+         g_debug("next_occur past end date");
          g_date_clear( &next_occur, 1 );
       }
    } else if ( xaccSchedXactionHasOccurDef( sx ) ) {
       if ( stateData ) {
          temporalStateData *tsd = (temporalStateData*)stateData;
          if ( tsd->num_occur_rem == 0 ) {
-            PINFO( "no more occurances remain" );
+            g_debug("no more occurances remain");
             g_date_clear( &next_occur, 1 );
          }
       } else {
@@ -511,7 +566,7 @@ xaccSchedXactionGetInstanceAfter( SchedXaction *sx,
       g_date_subtract_days( &prev_occur, 1 );
    }
 
-   xaccFreqSpecGetNextInstance( sx->freq, &prev_occur, &next_occur );
+   recurrenceListNextInstance(sx->schedule, &prev_occur, &next_occur);
 
    if ( xaccSchedXactionHasEndDate( sx ) ) {
       GDate *end_date;
@@ -536,7 +591,7 @@ xaccSchedXactionGetInstanceAfter( SchedXaction *sx,
 }
 
 gint
-gnc_sx_get_instance_count( SchedXaction *sx, void *stateData )
+gnc_sx_get_instance_count( const SchedXaction *sx, void *stateData )
 {
   gint toRet = -1;
   temporalStateData *tsd;
@@ -552,14 +607,16 @@ gnc_sx_get_instance_count( SchedXaction *sx, void *stateData )
 }
 
 void
-gnc_sx_set_instance_count( SchedXaction *sx, gint instanceNum )
+gnc_sx_set_instance_count(SchedXaction *sx, gint instance_num)
 {
-  g_return_if_fail( sx );
-  sx->instance_num = instanceNum;
+  g_return_if_fail(sx);
+  if (sx->instance_num == instance_num)
+    return;
+  sx->instance_num = instance_num;
 }
 
 GList *
-xaccSchedXactionGetSplits( SchedXaction *sx )
+xaccSchedXactionGetSplits( const SchedXaction *sx )
 {
   g_return_val_if_fail( sx, NULL );
   return xaccAccountGetSplitList(sx->template_acct);
@@ -651,6 +708,8 @@ xaccSchedXactionSetTemplateTrans(SchedXaction *sx, GList *t_t_list,
     xaccTransSetDescription(new_trans, 
              gnc_ttinfo_get_description(tti));
 
+    xaccTransSetDatePostedSecs(new_trans, time(NULL));
+
     xaccTransSetNum(new_trans,
           gnc_ttinfo_get_num(tti));
     xaccTransSetCurrency( new_trans,
@@ -734,12 +793,14 @@ _temporal_state_data_cmp( gconstpointer a, gconstpointer b )
 
    if ( !tsd_a && !tsd_b )
       return 0;
+   if (tsd_a == tsd_b)
+      return 0;
    if ( !tsd_a )
       return 1;
    if ( !tsd_b )
       return -1;
    return g_date_compare( &tsd_a->last_date,
-                &tsd_b->last_date );
+                          &tsd_b->last_date );
 }
 
 /**
@@ -749,9 +810,9 @@ _temporal_state_data_cmp( gconstpointer a, gconstpointer b )
 void
 gnc_sx_add_defer_instance( SchedXaction *sx, void *deferStateData )
 {
-   sx->deferredList = g_list_insert_sorted( sx->deferredList,
-                   deferStateData,
-                   _temporal_state_data_cmp );
+    sx->deferredList = g_list_insert_sorted( sx->deferredList,
+                                             deferStateData,
+                                             _temporal_state_data_cmp );
 }
 
 /**
@@ -761,7 +822,17 @@ gnc_sx_add_defer_instance( SchedXaction *sx, void *deferStateData )
 void
 gnc_sx_remove_defer_instance( SchedXaction *sx, void *deferStateData )
 {
-   sx->deferredList = g_list_remove( sx->deferredList, deferStateData );
+    GList *found_by_value;
+
+    found_by_value = g_list_find_custom(
+        sx->deferredList, deferStateData, _temporal_state_data_cmp);
+    if (found_by_value == NULL) {
+        g_warning("unable to find deferred instance");
+        return;
+    }
+
+    gnc_sx_destroy_temporal_state(found_by_value->data);
+    sx->deferredList = g_list_delete_link(sx->deferredList, found_by_value);
 }
 
 /**
@@ -795,8 +866,6 @@ gboolean
 SXRegister(void)
 {
 	static QofParam params[] = {
-	 { GNC_SX_FREQ_SPEC, QOF_ID_FREQSPEC, (QofAccessFunc)xaccSchedXactionGetFreqSpec,
-		 (QofSetterFunc)xaccSchedXactionSetFreqSpec },
 	 { GNC_SX_NAME, QOF_TYPE_STRING, (QofAccessFunc)xaccSchedXactionGetName,
 		 (QofSetterFunc)xaccSchedXactionSetName },
 	 { GNC_SX_START_DATE, QOF_TYPE_DATE, (QofAccessFunc)xaccSchedXactionGetStartDate,
