@@ -35,7 +35,6 @@
 #include <unistd.h>
 
 #include "AccountP.h"
-#include "Group.h"
 #include "Scrub.h"
 #include "Scrub3.h"
 #include "TransactionP.h"
@@ -179,7 +178,7 @@ static QofLogModule log_module = GNC_MOD_ENGINE;
 
 void check_open (const Transaction *trans)
 {
-  if (trans && 0 >= trans->inst.editlevel)
+  if (trans && 0 >= qof_instance_get_editlevel(trans))
     PERR ("transaction %p not open for editing", trans);
 }
 /********************************************************************\
@@ -187,7 +186,7 @@ void check_open (const Transaction *trans)
 gboolean
 xaccTransStillHasSplit(const Transaction *trans, const Split *s)
 {
-    return (s->parent == trans && !s->inst.do_free);
+    return (s->parent == trans && !qof_instance_get_destroying(s));
 }
 
 /* Executes 'cmd_block' for each split currently in the transaction,
@@ -220,17 +219,36 @@ void gen_event_trans (Transaction *trans)
     Account *account = s->acc;
     GNCLot *lot = s->lot;
     if (account)
-      qof_event_gen (&account->inst.entity, GNC_EVENT_ITEM_CHANGED, s);
+      qof_event_gen (&account->inst, GNC_EVENT_ITEM_CHANGED, s);
 
     if (lot)
     {
       /* A change of transaction date might affect opening date of lot */
-      qof_event_gen (&lot->inst.entity, QOF_EVENT_MODIFY, NULL);
+      qof_event_gen (&lot->inst, QOF_EVENT_MODIFY, NULL);
     }
   }
 #endif
 }
 
+/* GObject Initialization */
+QOF_GOBJECT_IMPL(gnc_transaction, Transaction, QOF_TYPE_INSTANCE);
+
+static void
+gnc_transaction_init(Transaction* txn)
+{
+}
+
+static void
+gnc_transaction_dispose_real (GObject *txnp)
+{
+}
+
+static void
+gnc_transaction_finalize_real(GObject* txnp)
+{
+}
+
+
 /********************************************************************\
  * xaccInitTransaction
  * Initialize a transaction structure
@@ -253,13 +271,10 @@ xaccInitTransaction (Transaction * trans, QofBook *book)
   trans->date_posted.tv_sec  = 0;
   trans->date_posted.tv_nsec = 0;
 
-  trans->version = 0;
-  trans->version_check = 0;
   trans->marker = 0;
   trans->orig = NULL;
 
-  trans->idata = 0;
-  qof_instance_init (&trans->inst, GNC_ID_TRANS, book);
+  qof_instance_init_data (&trans->inst, GNC_ID_TRANS, book);
   LEAVE (" ");
 }
 
@@ -273,9 +288,9 @@ xaccMallocTransaction (QofBook *book)
 
   g_return_val_if_fail (book, NULL);
 
-  trans = g_new(Transaction, 1);
+  trans = g_object_new(GNC_TYPE_TRANSACTION, NULL);
   xaccInitTransaction (trans, book);
-  qof_event_gen (&trans->inst.entity, QOF_EVENT_CREATE, NULL);
+  qof_event_gen (&trans->inst, QOF_EVENT_CREATE, NULL);
 
   return trans;
 }
@@ -294,11 +309,11 @@ xaccTransDump (const Transaction *trans, const char *tag)
          trans->description ? trans->description : "(null)");
   printf("    Currency:    %s\n", 
          gnc_commodity_get_printname(trans->common_currency));
-  printf("    version:     %x\n", trans->version);
-  printf("    version_chk: %x\n", trans->version_check);
-  printf("    editlevel:   %x\n", trans->editlevel);
+  printf("    version:     %x\n", qof_instance_get_version(trans));
+  printf("    version_chk: %x\n", qof_instance_get_version_check(trans));
+  printf("    editlevel:   %x\n", qof_instance_get_editlevel(trans));
   printf("    orig:        %p\n", trans->orig);
-  printf("    idata:       %x\n", trans->idata);
+  printf("    idata:       %x\n", qof_instance_get_idata(trans));
   printf("    splits:      ");
   for (node = trans->splits; node; node = node->next)
   {
@@ -355,7 +370,7 @@ xaccDupeTransaction (const Transaction *t)
   Transaction *trans;
   GList *node;
 
-  trans = g_new0 (Transaction, 1);
+  trans = g_object_new (GNC_TYPE_TRANSACTION, NULL);
 
   trans->num         = CACHE_INSERT (t->num);
   trans->description = CACHE_INSERT (t->description);
@@ -368,7 +383,7 @@ xaccDupeTransaction (const Transaction *t)
 
   trans->date_entered = t->date_entered;
   trans->date_posted = t->date_posted;
-  trans->version = t->version;
+  qof_instance_copy_version(trans, t);
   trans->orig = NULL;
 
   trans->common_currency = t->common_currency;
@@ -377,12 +392,9 @@ xaccDupeTransaction (const Transaction *t)
    * the cloned transaction as something official.  If we ever 
    * use this transaction, we'll have to fix this up.
    */
-  trans->inst.entity.e_type = NULL;
-  trans->inst.entity.guid = *guid_null();
-  trans->inst.entity.collection = NULL;
-  trans->inst.book = t->inst.book;
-  trans->inst.editlevel = 0;
-  trans->inst.do_free = FALSE;
+  trans->inst.e_type = NULL;
+  qof_instance_set_guid(trans, guid_null());
+  qof_instance_copy_book(trans, t);
   trans->inst.kvp_data = kvp_frame_copy (t->inst.kvp_data);
 
   return trans;
@@ -400,20 +412,19 @@ xaccTransClone (const Transaction *t)
   GList *node;
 
   qof_event_suspend();
-  trans = g_new0 (Transaction, 1);
+  trans = g_object_new (GNC_TYPE_TRANSACTION, NULL);
 
   trans->date_entered    = t->date_entered;
   trans->date_posted     = t->date_posted;
   trans->num             = CACHE_INSERT (t->num);
   trans->description     = CACHE_INSERT (t->description);
   trans->common_currency = t->common_currency;
-  trans->version         = t->version;
-  trans->version_check   = t->version_check;
+  qof_instance_copy_version(trans, t);
+  qof_instance_copy_version_check(trans, t);
 
   trans->orig            = NULL;
-  trans->idata           = 0;
 
-  qof_instance_init (&trans->inst, GNC_ID_TRANS, t->inst.book);
+  qof_instance_init_data (&trans->inst, GNC_ID_TRANS, qof_instance_get_book(t));
   kvp_frame_delete (trans->inst.kvp_data);
   trans->inst.kvp_data    = kvp_frame_copy (t->inst.kvp_data);
 
@@ -468,7 +479,6 @@ xaccFreeTransaction (Transaction *trans)
   trans->date_entered.tv_nsec = 0;
   trans->date_posted.tv_sec = 0;
   trans->date_posted.tv_nsec = 0;
-  trans->version = 0;
 
   if (trans->orig)
   {
@@ -476,8 +486,8 @@ xaccFreeTransaction (Transaction *trans)
     trans->orig = NULL;
   }
 
-  qof_instance_release (&trans->inst);
-  g_free(trans);
+  /* qof_instance_release (&trans->inst); */
+  g_object_unref(trans);
 
   LEAVE ("(addr=%p)", trans);
 }
@@ -523,7 +533,7 @@ xaccTransEqual(const Transaction *ta, const Transaction *tb,
   if (ta == tb) return TRUE;
 
   if (check_guids) {
-    if (!guid_equal(&(ta->inst.entity.guid), &(tb->inst.entity.guid)))
+    if (qof_instance_guid_compare(ta, tb) != 0)
     {
       PWARN ("GUIDs differ");
       return FALSE;
@@ -778,7 +788,7 @@ xaccTransGetAccountBalance (const Transaction *trans,
 
     /* This test needs to correspond to the comparison function used when
        sorting the splits for computing the running balance. */
-    if (xaccSplitDateOrder (last_split, split) < 0)
+    if (xaccSplitOrder (last_split, split) < 0)
       last_split = split;
   }
 
@@ -826,7 +836,7 @@ xaccTransBeginEdit (Transaction *trans)
    if (!trans) return;
    if (!qof_begin_edit(&trans->inst)) return;
 
-   if (qof_book_shutting_down(trans->inst.book)) return;
+   if (qof_book_shutting_down(qof_instance_get_book(trans))) return;
 
    xaccOpenLog ();
    xaccTransWriteLog (trans, 'B');
@@ -845,9 +855,9 @@ xaccTransDestroy (Transaction *trans)
   if (!trans) return;
 
   if (!xaccTransGetReadOnly (trans) || 
-      qof_book_shutting_down(trans->inst.book)) {
+      qof_book_shutting_down(qof_instance_get_book(trans))) {
       xaccTransBeginEdit(trans);
-      trans->inst.do_free = TRUE;
+      qof_instance_set_destroying(trans, TRUE);
       xaccTransCommitEdit(trans);
   }
 }
@@ -876,7 +886,7 @@ static void
 do_destroy (Transaction *trans)
 {
   SplitList *node;
-  gboolean shutting_down = qof_book_shutting_down(trans->inst.book);
+  gboolean shutting_down = qof_book_shutting_down(qof_instance_get_book(trans));
 
   /* If there are capital-gains transactions associated with this, 
    * they need to be destroyed too.  */
@@ -886,7 +896,7 @@ do_destroy (Transaction *trans)
   if (!shutting_down)
     xaccTransWriteLog (trans, 'D');
 
-  qof_event_gen (&trans->inst.entity, QOF_EVENT_DESTROY, NULL);
+  qof_event_gen (&trans->inst, QOF_EVENT_DESTROY, NULL);
 
   /* We only own the splits that still think they belong to us. */
   trans->splits = g_list_copy(trans->splits);
@@ -947,21 +957,21 @@ static void trans_cleanup_commit(Transaction *trans)
         if (!qof_instance_is_dirty(QOF_INSTANCE(s)))
             continue;
 
-        if ((s->parent != trans) || s->inst.do_free) {
+        if ((s->parent != trans) || qof_instance_get_destroying(s)) {
             /* Existing split either moved to another transaction or
                was destroyed, drop from list */
             GncEventData ed;
             ed.node = trans;
             ed.idx = g_list_index(trans->splits, s);
             trans->splits = g_list_remove(trans->splits, s);
-            qof_event_gen(&s->inst.entity, QOF_EVENT_REMOVE, &ed);
+            qof_event_gen(&s->inst, QOF_EVENT_REMOVE, &ed);
         }
 
         if (s->parent == trans) {
             /* Split was either added, destroyed or just changed */
-            if (s->inst.do_free)
-                qof_event_gen(&s->inst.entity, QOF_EVENT_DESTROY, NULL);
-            else qof_event_gen(&s->inst.entity, QOF_EVENT_MODIFY, NULL);
+            if (qof_instance_get_destroying(s))
+                qof_event_gen(&s->inst, QOF_EVENT_DESTROY, NULL);
+            else qof_event_gen(&s->inst, QOF_EVENT_MODIFY, NULL);
             xaccSplitCommitEdit(s);
         }
     }
@@ -980,26 +990,31 @@ static void trans_cleanup_commit(Transaction *trans)
     xaccTransSortSplits(trans);
 
     /* Put back to zero. */
-    trans->inst.editlevel--;
-    g_assert(trans->inst.editlevel == 0);
+    qof_instance_decrease_editlevel(trans);
+    g_assert(qof_instance_get_editlevel(trans) == 0);
 
     gen_event_trans (trans); //TODO: could be conditional
-    qof_event_gen (&trans->inst.entity, QOF_EVENT_MODIFY, NULL);
+    qof_event_gen (&trans->inst, QOF_EVENT_MODIFY, NULL);
 }
 
 void
 xaccTransCommitEdit (Transaction *trans)
 {
    if (!trans) return;
+   ENTER ("(trans=%p)", trans);
 
-   if (!qof_commit_edit (QOF_INSTANCE(trans))) return;
+   if (!qof_commit_edit (QOF_INSTANCE(trans))) {
+       LEAVE("editlevel non-zero");
+       return;
+   }
 
    /* We increment this for the duration of the call
     * so other functions don't result in a recursive
     * call to xaccTransCommitEdit. */
-   trans->inst.editlevel++;
+   qof_instance_increase_editlevel(trans);
 
-   if (was_trans_emptied(trans)) trans->inst.do_free = TRUE;
+   if (was_trans_emptied(trans))
+     qof_instance_set_destroying(trans, TRUE);
 
    /* Before commiting the transaction, we're gonna enforce certain
     * constraints.  In particular, we want to enforce the cap-gains
@@ -1010,7 +1025,7 @@ xaccTransCommitEdit (Transaction *trans)
     * can cause pointers to splits and transactions to disapear out
     * from under the holder.
     */
-   if (!(trans->inst.do_free) && scrub_data && 
+   if (!qof_instance_get_destroying(trans) && scrub_data && 
        !qof_book_shutting_down(xaccTransGetBook(trans))) {
      /* If scrubbing gains recurses through here, don't call it again. */
      scrub_data = 0; 
@@ -1022,7 +1037,8 @@ xaccTransCommitEdit (Transaction *trans)
      /* Get the cap gains into a consistent state as well. */
      
      /* Lot Scrubbing is temporarily disabled. */
-     //xaccTransScrubGains (trans, NULL);
+     if (g_getenv("GNC_AUTO_SCRUB_LOTS") != NULL)
+         xaccTransScrubGains (trans, NULL);
 
      /* Allow scrubbing in transaction commit again */
      scrub_data = 1;
@@ -1135,7 +1151,7 @@ xaccTransRollbackEdit (Transaction *trans)
 
    /* Now that the engine copy is back to its original version,
     * get the backend to fix it in the database */
-   be = qof_book_get_backend (trans->inst.book);
+   be = qof_book_get_backend(qof_instance_get_book(trans));
    /** \todo Fix transrollbackedit in QOF so that rollback
    is exposed via the API. */
    if (be && be->rollback) 
@@ -1178,10 +1194,10 @@ xaccTransRollbackEdit (Transaction *trans)
    xaccFreeTransaction (trans->orig);
 
    trans->orig = NULL;
-   trans->inst.do_free = FALSE;
+   qof_instance_set_destroying(trans, FALSE);
 
    /* Put back to zero. */
-   trans->inst.editlevel--;
+   qof_instance_decrease_editlevel(trans);
    /* FIXME: The register code seems to depend on the engine to
       generate an event during rollback, even though the state is just
       reverting to what it was. */
@@ -1193,21 +1209,7 @@ xaccTransRollbackEdit (Transaction *trans)
 gboolean
 xaccTransIsOpen (const Transaction *trans)
 {
-  return trans ? (0 < trans->inst.editlevel) : FALSE;
-}
-
-/* Only used by postgres backend. Not sure if it should dirty the trans. */
-void
-xaccTransSetVersion (Transaction *trans, gint32 vers)
-{
-  if (trans) 
-      trans->version = vers;
-}
-
-gint32
-xaccTransGetVersion (const Transaction *trans)
-{
-  return trans ? trans->version : 0;
+  return trans ? (0 < qof_instance_get_editlevel(trans)) : FALSE;
 }
 
 #define SECS_PER_DAY 86400
@@ -1242,7 +1244,7 @@ xaccTransOrder (const Transaction *ta, const Transaction *tb)
     return retval;
 
   /* else, sort on guid - keeps sort stable. */
-  return guid_compare(&(ta->inst.entity.guid), &(tb->inst.entity.guid));
+  return qof_instance_guid_compare(ta, tb);
 }
 
 /********************************************************************\
@@ -1405,6 +1407,7 @@ xaccTransSetNum (Transaction *trans, const char *xnum)
 
    CACHE_REPLACE(trans->num, xnum);
    qof_instance_set_dirty(QOF_INSTANCE(trans));
+   mark_trans(trans);  /* Dirty balance of every account in trans */
    xaccTransCommitEdit(trans);
 }
 
@@ -1665,47 +1668,11 @@ guint
 gnc_book_count_transactions(QofBook *book)
 {
     guint count = 0;
-    xaccGroupForEachTransaction(xaccGetAccountGroup(book),
+    xaccAccountTreeForEachTransaction(gnc_book_get_root_account(book),
                                 counter_thunk, (void*)&count);
     return count;
 }
 
-/********************************************************************\
-\********************************************************************/
-/* walk through the splits, looking for any account */
-static Account * 
-get_any_account(const Transaction *trans)
-{
-    GList *node;
-    if (!trans) return NULL;
-    for (node = trans->splits; node; node = node->next)
-        if (((Split *)node->data)->acc)
-            return ((Split *)node->data)->acc;
-    return NULL;
-}
-Account *
-xaccGetAccountByName (const Transaction *trans, const char * name)
-{
-   Account *acc;
-   if (!trans || !name) return NULL;
-
-   acc = get_any_account(trans);
-   return acc ? xaccGetPeerAccountFromName (acc, name) : NULL;
-}
-
-/********************************************************************\
-\********************************************************************/
-
-Account *
-xaccGetAccountByFullName (const Transaction *trans, const char * name)
-{
-   Account *acc;
-   if (!trans || !name) return NULL;
-
-   acc = get_any_account(trans);
-   return acc ? xaccGetPeerAccountFromFullName (acc, name) : NULL;
-}
-
 /********************************************************************\
 \********************************************************************/
 
@@ -1826,7 +1793,7 @@ xaccTransGetReversedBy(const Transaction *trans)
 
     g_return_val_if_fail(trans, NULL);
     guid = kvp_frame_get_guid(trans->inst.kvp_data, TRANS_REVERSED_BY);
-    return xaccTransLookup(guid, trans->inst.book);
+    return xaccTransLookup(guid, qof_instance_get_book(trans));
 }
 
 void
