@@ -23,11 +23,43 @@
 #ifndef GNC_PRICEDB_H
 #define GNC_PRICEDB_H
 
+typedef struct _GncPriceClass GNCPriceClass;
+typedef struct _GncPriceDBClass GNCPriceDBClass;
+
 #include <stdio.h>
 #include "qof.h"
 #include "gnc-commodity.h"
 #include "gnc-engine.h"
 
+/* --- type macros --- */
+#define GNC_TYPE_PRICE            (gnc_price_get_type ())
+#define GNC_PRICE(o)              \
+     (G_TYPE_CHECK_INSTANCE_CAST ((o), GNC_TYPE_PRICE, GNCPrice))
+#define GNC_PRICE_CLASS(k)        \
+     (G_TYPE_CHECK_CLASS_CAST((k), GNC_TYPE_PRICE, GNCPriceClass))
+#define GNC_IS_PRICE(o)           \
+     (G_TYPE_CHECK_INSTANCE_TYPE ((o), GNC_TYPE_PRICE))
+#define GNC_IS_PRICE_CLASS(k)     \
+     (G_TYPE_CHECK_CLASS_TYPE ((k), GNC_TYPE_PRICE))
+#define GNC_PRICE_GET_CLASS(o)    \
+     (G_TYPE_INSTANCE_GET_CLASS ((o), GNC_TYPE_PRICE, GNCPriceClass))
+GType gnc_price_get_type(void);
+
+/* --- type macros --- */
+#define GNC_TYPE_PRICEDB            (gnc_pricedb_get_type ())
+#define GNC_PRICEDB(o)              \
+     (G_TYPE_CHECK_INSTANCE_CAST ((o), GNC_TYPE_PRICEDB, GNCPriceDB))
+#define GNC_PRICEDB_CLASS(k)        \
+     (G_TYPE_CHECK_CLASS_CAST((k), GNC_TYPE_PRICEDB, GNCPriceDBClass))
+#define GNC_IS_PRICEDB(o)           \
+     (G_TYPE_CHECK_INSTANCE_TYPE ((o), GNC_TYPE_PRICEDB))
+#define GNC_IS_PRICEDB_CLASS(k)     \
+     (G_TYPE_CHECK_CLASS_TYPE ((k), GNC_TYPE_PRICEDB))
+#define GNC_PRICEDB_GET_CLASS(o)    \
+     (G_TYPE_INSTANCE_GET_CLASS ((o), GNC_TYPE_PRICEDB, GNCPriceDBClass))
+GType gnc_pricedb_get_type(void);
+
+
 /** @addtogroup PriceDB
     @{ */
 /** @file gnc-pricedb.h
@@ -126,6 +158,7 @@
 
 /** */
 typedef struct gnc_price_lookup_s GNCPriceLookup;
+typedef GList PriceList;
 
 /* ------------------ */
 /** @name Constructors 
@@ -149,7 +182,7 @@ GNCPrice *gnc_price_clone(GNCPrice* p, QofBook *book);
    around (i.e. increase its reference count by 1). */
 void      gnc_price_ref(GNCPrice *p);
 
-/** gnc_price_ref - indicate you're finished with a price
+/** gnc_price_unref - indicate you're finished with a price
    (i.e. decrease its reference count by 1). */
 void      gnc_price_unref(GNCPrice *p);
 /**  @} */
@@ -175,9 +208,8 @@ void gnc_price_set_commodity(GNCPrice *p, gnc_commodity *c);
 void gnc_price_set_currency(GNCPrice *p, gnc_commodity *c);
 void gnc_price_set_time(GNCPrice *p, Timespec t);
 void gnc_price_set_source(GNCPrice *p, const char *source);
-void gnc_price_set_type(GNCPrice *p, const char* type);
+void gnc_price_set_typestr(GNCPrice *p, const char* type);
 void gnc_price_set_value(GNCPrice *p, gnc_numeric value);
-void gnc_price_set_version(GNCPrice *p, gint32 versn);
 /**  @} */
 
 /* ------------------ */
@@ -187,17 +219,16 @@ void gnc_price_set_version(GNCPrice *p, gint32 versn);
 /** As mentioned above all of the getters return data that's internal
    to the GNCPrice, not copies, so don't free these values. */
 GNCPrice *      gnc_price_lookup (const GUID *guid, QofBook *book);
-gnc_commodity * gnc_price_get_commodity(GNCPrice *p);
-gnc_commodity * gnc_price_get_currency(GNCPrice *p);
-Timespec        gnc_price_get_time(GNCPrice *p);
-const char *    gnc_price_get_source(GNCPrice *p);
-const char *    gnc_price_get_type(GNCPrice *p);
-gnc_numeric     gnc_price_get_value(GNCPrice *p);
-gint32          gnc_price_get_version(GNCPrice *p);
-gboolean        gnc_price_equal(GNCPrice *p1, GNCPrice *p2);
+gnc_commodity * gnc_price_get_commodity(const GNCPrice *p);
+gnc_commodity * gnc_price_get_currency(const GNCPrice *p);
+Timespec        gnc_price_get_time(const GNCPrice *p);
+const char *    gnc_price_get_source(const GNCPrice *p);
+const char *    gnc_price_get_typestr(const GNCPrice *p);
+gnc_numeric     gnc_price_get_value(const GNCPrice *p);
+gboolean        gnc_price_equal(const GNCPrice *p1, const GNCPrice *p2);
 
-#define gnc_price_get_guid(X)    qof_entity_get_guid(QOF_ENTITY(X))
-#define gnc_price_return_guid(X) (*(qof_entity_get_guid(QOF_ENTITY(X))))
+#define gnc_price_get_guid(X)    qof_entity_get_guid(QOF_INSTANCE(X))
+#define gnc_price_return_guid(X) (*(qof_entity_get_guid(QOF_INSTANCE(X))))
 #define gnc_price_get_book(X)    qof_instance_get_book(QOF_INSTANCE(X))
 /**  @} */
 
@@ -216,17 +247,18 @@ gboolean        gnc_price_equal(GNCPrice *p1, GNCPrice *p2);
 
 /** gnc_price_list_insert - insert a price into the given list, calling
      gnc_price_ref on it during the process. */
-gboolean gnc_price_list_insert(GList **prices, GNCPrice *p, gboolean check_dupl);
+gboolean gnc_price_list_insert(PriceList **prices, GNCPrice *p,
+                               gboolean check_dupl);
 
 /** gnc_price_list_remove - remove the price, p, from the given list,
      calling gnc_price_unref on it during the process. */
-gboolean gnc_price_list_remove(GList **prices, GNCPrice *p);
+gboolean gnc_price_list_remove(PriceList **prices, GNCPrice *p);
 
 /** gnc_price_list_destroy - destroy the given price list, calling
      gnc_price_unref on all the prices included in the list. */
-void     gnc_price_list_destroy(GList *prices);
+void     gnc_price_list_destroy(PriceList *prices);
 
-gboolean gnc_price_list_equal(GList *prices1, GList *prices2);
+gboolean gnc_price_list_equal(PriceList *prices1, PriceList *prices2);
 /**  @} */
 /**  @}  end of the Price doxygen group */
 
@@ -288,8 +320,8 @@ GNCPrice   * gnc_pricedb_lookup_latest(GNCPriceDB *db,
 /** gnc_pricedb_lookup_latest_any_currency - find the most recent prices
      for the given commodity in any available currency. Prices will be
      returned as a GNCPrice list (see above). */
-GList      *gnc_pricedb_lookup_latest_any_currency(GNCPriceDB *db,
-                                                   const gnc_commodity *commodity);
+PriceList * gnc_pricedb_lookup_latest_any_currency(GNCPriceDB *db,
+                                                 const gnc_commodity *commodity);
 
 /** gnc_pricedb_has_prices - return an indication of whether or not
     there are any prices for a given commodity in the given currency.
@@ -301,39 +333,39 @@ gboolean     gnc_pricedb_has_prices(GNCPriceDB *db,
 /** gnc_pricedb_get_prices - return all the prices for a given
      commodity in the given currency.  Returns NULL on failure.  The
      result is a GNCPrice list (see above).  */
-GList      * gnc_pricedb_get_prices(GNCPriceDB *db,
-                                    const gnc_commodity *commodity,
-                                    const gnc_commodity *currency);
+PriceList * gnc_pricedb_get_prices(GNCPriceDB *db,
+                                 const gnc_commodity *commodity,
+                                 const gnc_commodity *currency);
 
 /** gnc_pricedb_lookup_at_time - return all prices that match the given
      commodity, currency, and timespec.  Prices will be returned as a
      GNCPrice list (see above). */
-GList      * gnc_pricedb_lookup_at_time(GNCPriceDB *db,
-                                        const gnc_commodity *commodity,
-                                        const gnc_commodity *currency,
-                                        Timespec t);
+PriceList * gnc_pricedb_lookup_at_time(GNCPriceDB *db,
+                                     const gnc_commodity *commodity,
+                                     const gnc_commodity *currency,
+                                     Timespec t);
 
 /** gnc_pricedb_lookup_at_time_any_currency - return all prices that match the
      given commodity and timespec in any available currency.  Prices will be
      returned as a GNCPrice list (see above). */
-GList      * gnc_pricedb_lookup_at_time_any_currency(GNCPriceDB *db,
- 		                                     const gnc_commodity *c,
-		                                     Timespec t);
+PriceList * gnc_pricedb_lookup_at_time_any_currency(GNCPriceDB *db,
+                                                  const gnc_commodity *c,
+                                                  Timespec t);
 
 /** gnc_pricedb_lookup_day - return all prices that match the given
      commodity, currency, and timespec.  Prices will be returned as a
      GNCPrice list (see above). */
-GList      * gnc_pricedb_lookup_day(GNCPriceDB *db,
-				    const gnc_commodity *commodity,
-				    const gnc_commodity *currency,
-				    Timespec t);
+PriceList * gnc_pricedb_lookup_day(GNCPriceDB *db,
+                                 const gnc_commodity *commodity,
+                                 const gnc_commodity *currency,
+                                 Timespec t);
 
 /** gnc_pricedb_lookup_day_any_currency - return all prices that match the
      given commodity and timespec in any available currency.  Prices will be
      returned as a GNCPrice list (see above). */
-GList      * gnc_pricedb_lookup_day_any_currency(GNCPriceDB *db,
- 		                                 const gnc_commodity *c,
-		                                 Timespec t);
+PriceList * gnc_pricedb_lookup_day_any_currency(GNCPriceDB *db,
+                                              const gnc_commodity *c,
+                                              Timespec t);
 
 /** gnc_pricedb_lookup_nearest_in_time - return the price for the given
      commodity in the given currency nearest to the given time t. */
@@ -345,9 +377,9 @@ GNCPrice   * gnc_pricedb_lookup_nearest_in_time(GNCPriceDB *db,
 /** gnc_pricedb_lookup_nearest_in_time_any_currency - return all prices that
      match the given commodity and timespec in any available currency. Prices
      will be returned as a GNCPrice list (see above). */
-GList      * gnc_pricedb_lookup_nearest_in_time_any_currency(GNCPriceDB *db,
- 		                                             const gnc_commodity *c,
-		                                             Timespec t);
+PriceList * gnc_pricedb_lookup_nearest_in_time_any_currency(GNCPriceDB *db,
+                                                          const gnc_commodity *c,
+                                                          Timespec t);
 /** gnc_pricedb_lookup_latest_before - return the latest price for the given commodity
     in the given currency up to and including time t. */
 GNCPrice * gnc_pricedb_lookup_latest_before(GNCPriceDB *db,
@@ -358,9 +390,9 @@ GNCPrice * gnc_pricedb_lookup_latest_before(GNCPriceDB *db,
 /** gnc_pricedb_lookup_latest_before_any_currency - return recent prices that
      match the given commodity up to and including time t in any available currency. Prices
      will be returned as a GNCPrice list (see above). */
-GList      * gnc_pricedb_lookup_latest_before_any_currency(GNCPriceDB *db,
- 		                                             gnc_commodity *c,
-		                                             Timespec t);
+PriceList * gnc_pricedb_lookup_latest_before_any_currency(GNCPriceDB *db,
+                                                        gnc_commodity *c,
+                                                        Timespec t);
 
 
 /** gnc_pricedb_convert_balance_latest_price - Convert a balance
