@@ -11,7 +11,8 @@
 ;;   http://www.xe.com/iso4217.htm
 ;;   http://www.thefinancials.com/vortex/CurrencyFormats.html
 
-( "Afghanistan Afghani" "afghani" "pul" "ISO4217" "AFA" "004" 100 100 )
+( "Afghanistan Afghani (old)" "afghani" "pul" "ISO4217" "AFA" "004" 100 100 ) ;; through 2003-01-02
+( "Afghanistan Afghani" "afghani" "afghani" "ISO4217" "AFN" "971" 1 1 ) ;; from 2002-10-07
 ( "Albanian Lek" "lek" "qindarka" "ISO4217" "ALL" "008" 100 100 )
 ( "Algerian Dinar" "dinar" "centime"  "ISO4217" "DZD" "012" 100 100 )
 ( "Andorran Franc" "franc" "centime" "ISO4217" "ADF" "950" 100 100 ) ;; 1/1 French Franc
@@ -23,6 +24,7 @@
 ( "Australian Dollar" "dollar" "cent" "ISO4217" "AUD" "036" 100 100 )
 ( "Austrian Shilling" "shilling" "groschen"  "ISO4217" "ATS" "040" 100 100 ) ;; through 1998
 ( "Azerbaijani Manat" "manat" "gopik" "ISO4217" "AZM" "031" 100 100 )
+( "Azerbaijani Manat" "manat" "gopik" "ISO4217" "AZN" "944" 100 100 )
 ( "Bahamian Dollar" "dollar" "cent"  "ISO4217" "BSD" "044" 100 100 )
 ( "Bahraini Dinar" "dinar" "fil"  "ISO4217" "BHD" "048" 1000 1000 )
 ( "Bangladeshi Taka" "taka" "paisa"  "ISO4217" "BDT" "050" 100 100 )
@@ -55,10 +57,12 @@
 ( "Chilean Peso" "peso" "centavo" "ISO4217" "CLP" "152" 1 1 )
 ( "Chinese Yuan Renminbi" "renminbi" "fen" "ISO4217" "CNY" "156" 100 100 )
 ( "Colombian Peso" "peso" "centavo" "ISO4217" "COP" "170" 100 100 )
+;; ( "Colombian Unidad de Valor Real" "???" "???" "ISO4217" "COU" "970" 100 100)
 ( "Comoros Franc" "franc" "centime" "ISO4217" "KMF" "174" 1 1  )
 ( "Costa Rican Colon" "colon" "centimo" "ISO4217" "CRC" "188" 100 100 )
 ( "Croatian Kuna" "kuna" "lipa" "ISO4217" "HRK" "191" 100 100 )
 ( "Cuban Peso" "peso" "centavo" "ISO4217" "CUP" "192" 100 100 )
+( "Cuban Convertible Peso" "peso" "centavo" "ISO4217" "CUC" "XXX" 100 100 )
 ( "Cyprus Pound" "pound" "pence"  "ISO4217" "CYP" "196" 100 100 )
 ( "Czech Koruna" "koruna" "haleru" "ISO4217" "CZK" "203" 100 100  )
 ( "Danish Krone" "krone" "ore" "ISO4217" "DKK" "208" 100 100 )
@@ -129,7 +133,8 @@
 ( "Moldovan Leu" "leu" "ban" "ISO4217" "MDL" "498" 100 100 )
 ( "Mongolian Tugrik" "tugrik" "mongo" "ISO4217" "MNT" "496" 100 100 )
 ( "Moroccan Dirham" "dirham" "centime"  "ISO4217" "MAD" "504" 100 100 )
-( "Mozambique Metical" "metical" "centavo"  "ISO4217" "MZM" "508" 100 100 )
+( "Mozambique Metical" "metical" "centavo" "ISO4217" "MZM" "508" 100 100 )
+( "Mozambique Metical" "metical" "centavo" "ISO4217" "MZN" "943" 100 100 ) ;; 2006-07-01; <http://en.wikipedia.org/wiki/Mozambican_metical>
 ( "Myanmar Kyat" "kyat" "pya" "ISO4217" "MMK" "104" 100 100 )
 ( "Namibian Dollar" "dollar" "cent" "ISO4217" "NAD" "516" 100 100 )
 ( "Nepalese Rupee" "rupee" "paise" "ISO4217" "NPR" "524" 100 100 )
