@@ -21,6 +21,7 @@
  *  02110-1301, USA.
  */
  
+#include "config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include "qof.h"
@@ -42,5 +43,5 @@ main (int argc, char ** argv)
 		print_test_results();
 	}
 	qof_close();
-  return 0;
+  return get_rv();
 }
