@@ -23,6 +23,7 @@
  /*
  * Lightly test the QofObject infrastructure.
  */
+#include "config.h"
 #include <glib.h>
 #include <glib/gi18n.h>
 #include "qof.h"
@@ -32,7 +33,7 @@
 #define TEST_MODULE_NAME "object-test"
 #define TEST_MODULE_DESC "Test Object"
 
-static void obj_foreach (QofCollection *, QofEntityForeachCB, gpointer);
+static void obj_foreach (const QofCollection *, QofInstanceForeachCB, gpointer);
 static const char * printable (gpointer obj);
 static void test_printable (const char *name, gpointer obj);
 static void test_foreach (QofBook *, const char *);
@@ -78,7 +79,7 @@ test_object (void)
 }
 
 static void
-obj_foreach (QofCollection *col, QofEntityForeachCB cb, gpointer u_d)
+obj_foreach (const QofCollection *col, QofInstanceForeachCB cb, gpointer u_d)
 {
   int *foo = u_d;
 
@@ -88,7 +89,7 @@ obj_foreach (QofCollection *col, QofEntityForeachCB cb, gpointer u_d)
   *foo = 1;
 }
 
-static void foreachCB (QofEntity *ent, gpointer u_d)
+static void foreachCB (QofInstance *ent, gpointer u_d)
 {
   do_test (FALSE, "FAIL");
 }
@@ -153,5 +154,5 @@ main (int argc, char **argv)
 		print_test_results();
 	}
 	qof_close();
-  return 0;
+  return get_rv();
 }
