@@ -22,6 +22,7 @@
  *  02110-1301, USA.
  */
  
+#include "config.h"
 #include <glib.h>
 #include <string.h>
 #include "cashobjects.h"
@@ -192,14 +193,14 @@ run_test (void)
 int
 main (int argc, char **argv)
 {
-	qof_init();
-	if(cashobjects_register())
-	{
-  xaccLogDisable ();
-  run_test ();
-  success("transaction voiding seems OK");
-  print_test_results();
-	}
-	qof_close();
-  return 0;
+  qof_init();
+  if(cashobjects_register())
+    {
+      xaccLogDisable ();
+      run_test ();
+      success("transaction voiding seems OK");
+      print_test_results();
+    }
+  qof_close();
+  return get_rv();
 }
