@@ -1,14 +1,13 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <guile/gh.h>
+#include <libguile.h>
 
 #include "gnc-module.h"
 
 static void
-guile_main(int argc, char ** argv) {
-  int       (*foo_hello)(void);
-  int helloval; 
+guile_main(void *closure, int argc, char ** argv)
+{
   GNCModule foo;
 
   printf("  test-load-c.c: testing module load/unload from C ... ");
@@ -21,13 +20,6 @@ guile_main(int argc, char ** argv) {
     printf("  Failed to load foo\n");
     exit(-1);
   }
-  
-  foo_hello = gnc_module_lookup(foo, "foo_hello");
-  helloval = foo_hello();
-  if(helloval != 10) {
-    printf("  Call of module function failed.\n");
-    exit(-1);
-  }
 
   if(!gnc_module_unload(foo)) {
     printf("  Failed to unload foo\n");
@@ -39,7 +31,8 @@ guile_main(int argc, char ** argv) {
 }
 
 int
-main(int argc, char ** argv) {
-  gh_enter(argc, argv, guile_main);
+main(int argc, char ** argv)
+{
+  scm_boot_guile(argc, argv, guile_main, NULL);
   return 0;
 }
