@@ -1359,6 +1359,10 @@ gnc_preferences_response_cb(GtkDialog *dialog, gint response, GtkDialog *unused)
      gnc_save_window_size(GCONF_SECTION, GTK_WINDOW(dialog));
      gnc_unregister_gui_component_by_data(DIALOG_PREFERENCES_CM_CLASS,
 					  dialog);
+     gnc_gconf_general_remove_cb(
+       KEY_ACCOUNT_SEPARATOR,
+       (GncGconfGeneralCb)gnc_account_separator_prefs_cb,
+       dialog);
      gnc_gconf_remove_notification(G_OBJECT(dialog), NULL,
 				   DIALOG_PREFERENCES_CM_CLASS);
      gtk_widget_destroy(GTK_WIDGET(dialog));
