@@ -37,8 +37,7 @@
 
 #include "dialog-utils.h"
 #include "gnc-commodity.h"
-#include "Group.h"
-#include "gnc-dir.h"
+#include "gnc-path.h"
 #include "gnc-engine.h"
 #include "gnc-euro.h"
 #include "gnc-ui-util.h"
@@ -100,8 +99,12 @@ gnc_build_option_menu(GNCOptionInfo *option_info, gint num_options)
 
   tooltips = gtk_tooltips_new();
 
+#ifdef HAVE_GTK_2_10
+  g_object_ref_sink(tooltips);
+#else
   g_object_ref (tooltips);
   gtk_object_sink (GTK_OBJECT (tooltips));
+#endif
 
   for (i = 0; i < num_options; i++)
   {
@@ -613,16 +616,15 @@ check_realize (GtkWidget *widget, gpointer user_data)
   GList *list;
   GList *node;
   GdkGC *gc;
-  GdkFont *font;
+  PangoLayout *layout;
 
   if (check_info->mask)
     return;
 
-  style = gtk_widget_get_style (widget);
-  font = gdk_font_from_description(style->font_desc);
-
-  font_height = font->ascent + font->descent;
-  check_size = (font_height > 0) ? font_height - 3 : 9;
+  layout = gtk_widget_create_pango_layout(widget, "sample");
+  pango_layout_get_pixel_size(layout, NULL,  &font_height);
+  g_object_unref(layout);
+  check_size = (font_height > 0) ? font_height - 6 : 9;
 
   check_info->mask = gdk_pixmap_new (NULL, check_size, check_size, 1);
 
@@ -632,6 +634,7 @@ check_realize (GtkWidget *widget, gpointer user_data)
   check_info->off_pixmap = gdk_pixmap_new (widget->window,
                                            check_size, check_size, -1);
 
+  style = gtk_widget_get_style (widget);
   gc_values.foreground = style->white;
   gc = gtk_gc_get (1, gtk_widget_get_colormap (widget),
                    &gc_values, GDK_GC_FOREGROUND);
@@ -807,6 +810,7 @@ gnc_glade_xml_new (const char *filename, const char *root)
 {
   GladeXML *xml;
   char *fname;
+  gchar *gnc_glade_dir;
 
   g_return_val_if_fail (filename != NULL, NULL);
   g_return_val_if_fail (root != NULL, NULL);
@@ -817,7 +821,9 @@ gnc_glade_xml_new (const char *filename, const char *root)
     glade_inited = TRUE;
   }
 
-  fname = g_strconcat (GNC_GLADE_DIR, "/", filename, (char *)NULL);
+  gnc_glade_dir = gnc_path_get_gladedir ();
+  fname = g_build_filename(gnc_glade_dir, filename, (char *)NULL);
+  g_free (gnc_glade_dir);
 
   xml = glade_xml_new (fname, root, NULL);
 
@@ -902,16 +908,12 @@ gnc_gtk_dialog_add_button (GtkWidget *dialog, const gchar *label, const gchar *s
   GtkWidget *button;
 
   button = gtk_button_new_with_label(label);
-#ifdef HAVE_GTK26
   if (stock_id) {
     GtkWidget *image;
 
     image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON);
     gtk_button_set_image(GTK_BUTTON(button), image);
   }
-#else
-  gtk_button_set_use_underline(GTK_BUTTON(button), TRUE);
-#endif
   gtk_widget_show_all(button);
   gtk_dialog_add_action_widget(GTK_DIALOG(dialog), button, response);
 }
@@ -980,61 +982,3 @@ gnc_dialog_run (GtkDialog *dialog, const gchar *gconf_key)
 
     return response;
 }
-
-#ifndef HAVE_GTK26
-
-/** Find the first GtkLabel in a container. When called on a gtk2.4
- *  message dialog, there is only one label in the dialog so theis
- *  should return it. */
-static void
-find_label (GtkWidget *widget, gpointer data)
-{
-  GtkWidget **label = data;
-
-  if (*label)
-    return;
-
-  if (GTK_IS_LABEL(widget)) {
-    *label = widget;
-    return;
-  }
-
-  if (GTK_IS_CONTAINER(widget)) {
-    gtk_container_foreach(GTK_CONTAINER(widget), find_label, data);
-  }
-}
-
-/** Mimic the gtk2.6 function to add secondary information to a
- *  message dialog. */
-void
-gtk_message_dialog_format_secondary_text(GtkMessageDialog *dialog,
-					 const gchar *format,
-					 ...)
-{
-  GtkWidget *label = NULL;
-  const gchar *current;
-  gchar *primary, *secondary;
-  va_list args;
-
-  gtk_container_foreach(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox),
-			find_label, &label);
-  if (!label)
-    return;
-
-  /* Get the current markup. */
-  current = gtk_label_get_label(GTK_LABEL(label));
-
-  /* Format the text to be added. */
-  va_start(args, format);
-  secondary = g_strdup_vprintf(format, args);
-  va_end(args);
-
-  /* Append the two strings, making the first one bold. */
-  primary = g_strdup_printf("<b>%s</b>\n\n%s", current, secondary);
-  gtk_label_set_markup(GTK_LABEL(label), primary);
-
-  g_free(primary);
-  g_free(secondary);
-}
-
-#endif
