@@ -53,7 +53,7 @@ static void gnc_tree_model_commodity_finalize (GObject *object);
 static void gnc_tree_model_commodity_dispose (GObject *object);
 
 static void gnc_tree_model_commodity_tree_model_init (GtkTreeModelIface *iface);
-static guint gnc_tree_model_commodity_get_flags (GtkTreeModel *tree_model);
+static GtkTreeModelFlags gnc_tree_model_commodity_get_flags (GtkTreeModel *tree_model);
 static int gnc_tree_model_commodity_get_n_columns (GtkTreeModel *tree_model);
 static GType gnc_tree_model_commodity_get_column_type (GtkTreeModel *tree_model,
 						       int index);
@@ -82,7 +82,7 @@ static gboolean	gnc_tree_model_commodity_iter_nth_child (GtkTreeModel *tree_mode
 static gboolean	gnc_tree_model_commodity_iter_parent (GtkTreeModel *tree_model,
 						      GtkTreeIter *iter,
     						      GtkTreeIter *child);
-static void gnc_tree_model_commodity_event_handler (QofEntity *entity,
+static void gnc_tree_model_commodity_event_handler (QofInstance *entity,
 						    QofEventId event_type,
 						    gpointer user_data,
 						    gpointer event_data);
@@ -164,11 +164,11 @@ gnc_tree_model_commodity_finalize (GObject *object)
 	GncTreeModelCommodity *model;
 	GncTreeModelCommodityPrivate *priv;
 
-	ENTER("model %p", object);
-
 	g_return_if_fail (object != NULL);
 	g_return_if_fail (GNC_IS_TREE_MODEL_COMMODITY (object));
 
+	ENTER("model %p", object);
+
 	model = GNC_TREE_MODEL_COMMODITY (object);
 	priv = GNC_TREE_MODEL_COMMODITY_GET_PRIVATE(model);
 	priv->book = NULL;
@@ -184,10 +184,10 @@ gnc_tree_model_commodity_dispose (GObject *object)
 	GncTreeModelCommodity *model;
 	GncTreeModelCommodityPrivate *priv;
 
-	ENTER("model %p", object);
 	g_return_if_fail (object != NULL);
 	g_return_if_fail (GNC_IS_TREE_MODEL_COMMODITY (object));
 
+	ENTER("model %p", object);
 	model = GNC_TREE_MODEL_COMMODITY (object);
 	priv = GNC_TREE_MODEL_COMMODITY_GET_PRIVATE(model);
 
@@ -208,6 +208,8 @@ gnc_tree_model_commodity_new (QofBook *book, gnc_commodity_table *ct)
 	GncTreeModelCommodityPrivate *priv;
 	const GList *item;
 
+    ENTER("");
+
 	item = gnc_gobject_tracking_get_list(GNC_TREE_MODEL_COMMODITY_NAME);
 	for ( ; item; item = g_list_next(item)) {
 		model = (GncTreeModelCommodity *)item->data;
@@ -227,6 +229,7 @@ gnc_tree_model_commodity_new (QofBook *book, gnc_commodity_table *ct)
 	priv->event_handler_id =
 	  qof_event_register_handler (gnc_tree_model_commodity_event_handler, model);
 
+    LEAVE("");
 	return GTK_TREE_MODEL (model);
 }
 
@@ -305,7 +308,7 @@ iter_to_string (GtkTreeIter *iter)
 
   string = g_static_private_get (&gtmits_buffer_key);
   if (string == NULL) {
-    string = malloc(ITER_STRING_LEN + 1);
+    string = g_malloc(ITER_STRING_LEN + 1);
     g_static_private_set (&gtmits_buffer_key, string, g_free);
   }
 #else
@@ -366,7 +369,7 @@ gnc_tree_model_commodity_tree_model_init (GtkTreeModelIface *iface)
 	iface->iter_parent     = gnc_tree_model_commodity_iter_parent;
 }
 
-static guint
+static GtkTreeModelFlags
 gnc_tree_model_commodity_get_flags (GtkTreeModel *tree_model)
 {
 	return 0;
@@ -447,7 +450,10 @@ gnc_tree_model_commodity_get_iter (GtkTreeModel *tree_model,
 
 	list = gnc_commodity_table_get_namespaces_list(ct);
 	i = gtk_tree_path_get_indices (path)[0];
-	g_return_val_if_fail (i >= 0 && i < g_list_length (list), FALSE);
+    {
+         if (!(i >= 0 && i < g_list_length (list))) { LEAVE(""); }
+         g_return_val_if_fail (i >= 0 && i < g_list_length (list), FALSE);
+    }
 	namespace = g_list_nth_data (list, i);
 
 	if (depth == 1) {
@@ -461,7 +467,10 @@ gnc_tree_model_commodity_get_iter (GtkTreeModel *tree_model,
 
 	list = gnc_commodity_namespace_get_commodity_list(namespace);
 	i = gtk_tree_path_get_indices (path)[1];
-	g_return_val_if_fail (i >= 0 && i < g_list_length (list), FALSE);
+    {
+         if (!(i >= 0 && i < g_list_length (list))) { LEAVE(""); }
+         g_return_val_if_fail (i >= 0 && i < g_list_length (list), FALSE);
+    }
 	commodity = g_list_nth_data (list, i);
 
 	iter->stamp      = model->stamp;
@@ -483,13 +492,13 @@ gnc_tree_model_commodity_get_path (GtkTreeModel *tree_model,
 	gnc_commodity_namespace *namespace;
 	GList *ns_list;
 
-	ENTER("model %p, iter %p (%s)", tree_model, iter, iter_to_string(iter));
 	g_return_val_if_fail (GNC_IS_TREE_MODEL_COMMODITY (tree_model), NULL);
 	model = GNC_TREE_MODEL_COMMODITY (tree_model);
 	g_return_val_if_fail (iter != NULL, NULL);
 	g_return_val_if_fail (iter->user_data != NULL, NULL);
 	g_return_val_if_fail (iter->user_data2 != NULL, NULL);
 	g_return_val_if_fail (iter->stamp == model->stamp, NULL);
+	ENTER("model %p, iter %p (%s)", tree_model, iter, iter_to_string(iter));
 	
 	priv = GNC_TREE_MODEL_COMMODITY_GET_PRIVATE(model);
 	ct = priv->commodity_table;
@@ -640,7 +649,6 @@ gnc_tree_model_commodity_iter_next (GtkTreeModel *tree_model,
 	GList *list;
 	int n;
 
-	ENTER("model %p, iter %p(%s)", tree_model, iter, iter_to_string(iter));
 	g_return_val_if_fail (GNC_IS_TREE_MODEL_COMMODITY (tree_model), FALSE);
 	model = GNC_TREE_MODEL_COMMODITY (tree_model);
 	g_return_val_if_fail (iter != NULL, FALSE);
@@ -648,6 +656,7 @@ gnc_tree_model_commodity_iter_next (GtkTreeModel *tree_model,
 	g_return_val_if_fail (iter->user_data2 != NULL, FALSE);
 	g_return_val_if_fail (iter->stamp == model->stamp, FALSE);
 
+	ENTER("model %p, iter %p(%s)", tree_model, iter, iter_to_string(iter));
 	priv = GNC_TREE_MODEL_COMMODITY_GET_PRIVATE(model);
 	if (iter->user_data == ITER_IS_NAMESPACE) {
 	  ct = priv->commodity_table;
@@ -733,9 +742,9 @@ gnc_tree_model_commodity_iter_has_child (GtkTreeModel *tree_model,
 	gnc_commodity_namespace *namespace;
 	GList *list;
 
+	g_return_val_if_fail (iter != NULL, FALSE);
 	ENTER("model %p, iter %p (%s)", tree_model,
 	      iter, iter_to_string(iter));
-	g_return_val_if_fail (iter != NULL, FALSE);
 
 	if (iter->user_data != ITER_IS_NAMESPACE) {
 	  LEAVE("no children (not ns)");
@@ -886,11 +895,12 @@ gnc_tree_model_commodity_get_iter_from_commodity (GncTreeModelCommodity *model,
 	GList *list;
 	gint n;
 	
-	ENTER("model %p, commodity %p, iter %p", model, commodity, iter);
 	g_return_val_if_fail (GNC_IS_TREE_MODEL_COMMODITY (model), FALSE);
 	g_return_val_if_fail ((commodity != NULL), FALSE);
 	g_return_val_if_fail ((iter != NULL), FALSE);
 
+	ENTER("model %p, commodity %p, iter %p", model, commodity, iter);
+
 	namespace = gnc_commodity_get_namespace_ds(commodity);
 	if (namespace == NULL) {
 	  LEAVE("no namespace");
@@ -929,9 +939,9 @@ gnc_tree_model_commodity_get_path_from_commodity (GncTreeModelCommodity *model,
 	GtkTreeIter tree_iter;
 	GtkTreePath *tree_path;
 
-	ENTER("model %p, commodity %p", model, commodity);
 	g_return_val_if_fail (GNC_IS_TREE_MODEL_COMMODITY (model), NULL);
 	g_return_val_if_fail (commodity != NULL, NULL);
+	ENTER("model %p, commodity %p", model, commodity);
 
 	if (!gnc_tree_model_commodity_get_iter_from_commodity (model, commodity, &tree_iter)) {
 	  LEAVE("no iter");
@@ -963,19 +973,26 @@ gnc_tree_model_commodity_get_iter_from_namespace (GncTreeModelCommodity *model,
 	GList *list;
 	gint n;
 	
-	ENTER("model %p, namespace %p, iter %p", model, namespace, iter);
 	g_return_val_if_fail (GNC_IS_TREE_MODEL_COMMODITY (model), FALSE);
 	g_return_val_if_fail ((namespace != NULL), FALSE);
 	g_return_val_if_fail ((iter != NULL), FALSE);
 
+	ENTER("model %p, namespace %p, iter %p", model, namespace, iter);
+
 	priv = GNC_TREE_MODEL_COMMODITY_GET_PRIVATE(model);
 	list = gnc_commodity_table_get_namespaces_list(priv->commodity_table);
 	if (list == NULL)
+    {
+      LEAVE("");
 	  return FALSE;
+    }
 
 	n = g_list_index(list, namespace);
 	if (n == -1)
+    {
+      LEAVE("");
 	  return FALSE;
+    }
 
 	iter->stamp = model->stamp;
 	iter->user_data  = ITER_IS_NAMESPACE;
@@ -1045,29 +1062,28 @@ static void
 gnc_tree_model_commodity_path_added (GncTreeModelCommodity *model,
 				     GtkTreeIter *iter)
 {
-  gnc_commodity_namespace *namespace;
   GtkTreePath *path;
-  GtkTreeIter ns_iter;
-  GList *list;
+  GtkTreeModel *tree_model;
+  GtkTreeIter tmp_iter;
 
   ENTER("model %p, iter (%p)%s", model, iter, iter_to_string(iter));
+  tree_model = GTK_TREE_MODEL(model);
 
-  if (iter->user_data == ITER_IS_COMMODITY) {
-    /* Reach out and touch the namespace first */
-    gnc_tree_model_commodity_iter_parent (GTK_TREE_MODEL(model), &ns_iter, iter);
-    namespace = gnc_tree_model_commodity_get_namespace (model, &ns_iter);
-    list = gnc_commodity_namespace_get_commodity_list(namespace);
-    if (g_list_length(list) == 1) {
-      path = gnc_tree_model_commodity_get_path (GTK_TREE_MODEL(model), &ns_iter);
-      gtk_tree_model_row_changed(GTK_TREE_MODEL(model), path, &ns_iter);
-      gtk_tree_model_row_has_child_toggled(GTK_TREE_MODEL(model), path, &ns_iter);
-      gtk_tree_path_free(path);
-    }
+  /* For either namespace or commodity */
+  path = gnc_tree_model_commodity_get_path(tree_model, iter);
+  gtk_tree_model_row_inserted(tree_model, path, iter);
+
+  /*  */
+  gtk_tree_path_up(path);
+  while (gtk_tree_path_get_depth(path) != 0) {
+      if (gtk_tree_model_get_iter(tree_model, &tmp_iter, path)) {
+          gtk_tree_model_row_changed(tree_model, path, &tmp_iter);
+          if (gtk_tree_model_iter_n_children(tree_model, &tmp_iter) == 1) {
+              gtk_tree_model_row_has_child_toggled(tree_model, path, &tmp_iter);
+          }
+      }
+      gtk_tree_path_up(path);
   }
-
-  /* Now for either namespace or commodity */
-  path = gnc_tree_model_commodity_get_path (GTK_TREE_MODEL(model), iter);
-  gtk_tree_model_row_inserted (GTK_TREE_MODEL(model), path, iter);
   gtk_tree_path_free(path);
 
   do {
@@ -1093,13 +1109,16 @@ gnc_tree_model_commodity_path_added (GncTreeModelCommodity *model,
  */
 static void
 gnc_tree_model_commodity_path_deleted (GncTreeModelCommodity *model,
-				       GtkTreePath *path)
+				       GtkTreePath *path_in)
 {
   gnc_commodity_namespace *namespace;
+  GtkTreePath *path;
   GtkTreeIter iter;
   GList *list;
   gint depth;
+  gboolean del_row = TRUE;
 
+  path = gtk_tree_path_copy(path_in);
   debug_path(ENTER, path);
 
   depth = gtk_tree_path_get_depth(path);
@@ -1114,13 +1133,20 @@ gnc_tree_model_commodity_path_deleted (GncTreeModelCommodity *model,
       gtk_tree_model_row_changed (GTK_TREE_MODEL(model), path, &iter);
       namespace = gnc_tree_model_commodity_get_namespace (model, &iter);
       if (namespace) {
-	list = gnc_commodity_namespace_get_commodity_list(namespace);
-	if (g_list_length(list) == 0) {
-	  gtk_tree_model_row_has_child_toggled(GTK_TREE_MODEL(model), path, &iter);
-	}
+           list = gnc_commodity_namespace_get_commodity_list(namespace);
+           if (g_list_length(list) == 0) {
+                gtk_tree_model_row_has_child_toggled(GTK_TREE_MODEL(model), path, &iter);
+                del_row = FALSE;
+           }
       }
     }
   }
+  gtk_tree_path_free(path);
+
+  /* Delete the row, if it hasn't already been deleted by an update of
+   * the parent row. */
+  if (del_row)
+    gtk_tree_model_row_deleted (GTK_TREE_MODEL(model), path_in);
 
   do {
     model->stamp++;
@@ -1156,7 +1182,6 @@ gnc_tree_model_commodity_do_deletions (gpointer unused)
     data = iter->data;
     pending_removals = g_slist_delete_link (pending_removals, iter);
 
-    gtk_tree_model_row_deleted (GTK_TREE_MODEL(data->model), data->path);
     gnc_tree_model_commodity_path_deleted (data->model, data->path);
     gtk_tree_path_free(data->path);
     g_free(data);
@@ -1195,7 +1220,7 @@ gnc_tree_model_commodity_do_deletions (gpointer unused)
  *  @param event_data A pointer to additional data about this event.
  */
 static void
-gnc_tree_model_commodity_event_handler (QofEntity *entity,
+gnc_tree_model_commodity_event_handler (QofInstance *entity,
 					QofEventId event_type,
 					gpointer user_data,
 					gpointer event_data)
@@ -1206,13 +1231,14 @@ gnc_tree_model_commodity_event_handler (QofEntity *entity,
 	remove_data *data;
 	const gchar *name;
 
-	ENTER("entity %p, event %d, model %p, event data %p",
-	      entity, event_type, user_data, event_data);
 	model = (GncTreeModelCommodity *)user_data;
 
 	/* hard failures */
 	g_return_if_fail(GNC_IS_TREE_MODEL_COMMODITY(model));
 
+	ENTER("entity %p, event %d, model %p, event data %p",
+	      entity, event_type, user_data, event_data);
+
 	/* get type specific data */
 	if (GNC_IS_COMMODITY(entity)) {
 	  gnc_commodity *commodity;
@@ -1237,6 +1263,7 @@ gnc_tree_model_commodity_event_handler (QofEntity *entity,
 	    }
 	  }
 	} else {
+      LEAVE("");
 	  return;
 	}
 
@@ -1256,7 +1283,7 @@ gnc_tree_model_commodity_event_handler (QofEntity *entity,
 	    return;
 	  }
 
-	  data = malloc(sizeof(*data));
+	  data = g_new0 (remove_data, 1);
 	  data->model = model;
 	  data->path = path;
 	  pending_removals = g_slist_append (pending_removals, data);
