@@ -27,6 +27,7 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <libguile.h>
+#include "guile-mappings.h"
 #include <time.h>
 
 #include "dialog-utils.h"
@@ -45,7 +46,7 @@
 #include "gnc-ui-util.h"
 #include "guile-util.h"
 #include "engine-helpers.h"
-#include <g-wrap-wct.h>
+#include "swig-runtime.h"
 
 
 #define DIALOG_PRICE_DB_CM_CLASS "dialog-price-edit-db"
@@ -262,7 +263,7 @@ gnc_prices_dialog_get_quotes_clicked (GtkWidget *widget, gpointer data)
   PricesDialog *pdb_dialog = data;
   SCM quotes_func;
   SCM book_scm;
-  SCM scm_window, window_type;
+  SCM scm_window;
 
   ENTER(" ");
   quotes_func = scm_c_eval_string ("gnc:book-add-quotes");
@@ -277,8 +278,8 @@ gnc_prices_dialog_get_quotes_clicked (GtkWidget *widget, gpointer data)
     return;
   }
 
-  window_type = scm_c_eval_string("<gtk:Widget*>");
-  scm_window = gw_wcp_assimilate_ptr(pdb_dialog->dialog, window_type);
+  scm_window =  SWIG_NewPointerObj(pdb_dialog->dialog,
+                                   SWIG_TypeQuery("_p_GtkWidget"), 0);
 
   gnc_set_busy_cursor (NULL, TRUE);
   scm_call_2 (quotes_func, scm_window, book_scm);
