@@ -17,13 +17,14 @@
  * along with this program; if not, contact:                        *
  *                                                                  *
  * Free Software Foundation           Voice:  +1-617-542-5942       *
- * 59 Temple Place - Suite 330        Fax:    +1-617-542-2652       *
- * Boston, MA  02111-1307,  USA       gnu@gnu.org                   *
+ * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
+ * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
 \********************************************************************/
 
 #include "config.h"
 
-#include <gnome.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
 
 #include "dialog-utils.h"
 #include "gnc-ui.h"
@@ -50,16 +51,15 @@ gnc_hbci_get_password (GtkWidget *parent,
   dialog = glade_xml_get_widget (xml, "Password Dialog");
 
   if (parent)
-    gnome_dialog_set_parent (GNOME_DIALOG (dialog), GTK_WINDOW (parent));
+    gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (parent));
 
   heading_label  = glade_xml_get_widget (xml, "heading_label");
   password_entry = glade_xml_get_widget (xml, "password_entry");
   g_assert(heading_label && password_entry);
 
-  gnome_dialog_set_default (GNOME_DIALOG (dialog), 0);
+  gtk_dialog_set_default_response (GTK_DIALOG (dialog), 1);
 
-  gnome_dialog_editable_enters (GNOME_DIALOG (dialog),
-                                GTK_EDITABLE (password_entry));
+  gtk_entry_set_activates_default (GTK_ENTRY (password_entry), TRUE);
 
   if (windowtitle)
     gtk_window_set_title (GTK_WINDOW (dialog), windowtitle);
@@ -71,25 +71,17 @@ gnc_hbci_get_password (GtkWidget *parent,
     gtk_entry_set_text (GTK_ENTRY (password_entry), initial_password);
   gtk_entry_set_visibility (GTK_ENTRY (password_entry), !hide_input);
 
-  gtk_widget_grab_focus (password_entry);
+  result = gtk_dialog_run (GTK_DIALOG (dialog));
 
-  /* Hide on close instead of destroy since we still need the values
-     from the boxes. */
-  gnome_dialog_close_hides (GNOME_DIALOG (dialog), TRUE);
-
-  result = gnome_dialog_run_and_close (GNOME_DIALOG (dialog));
-
-  if (result == 0)
+  if (result == 1) /* the hand-assigned response value */
   {
-    *password = gtk_editable_get_chars (GTK_EDITABLE (password_entry), 0, -1);
-
-    gtk_widget_destroy (GTK_WIDGET (dialog));
+    *password = g_strdup (gtk_entry_get_text (GTK_ENTRY (password_entry)) );
+    gtk_widget_destroy(dialog);
     return TRUE;
   }
+  gtk_widget_destroy(dialog);
 
   *password = NULL;
-
-  gtk_widget_destroy (GTK_WIDGET (dialog));
   return FALSE;
 }
 
@@ -114,19 +106,17 @@ gnc_hbci_get_initial_password (GtkWidget *parent,
   dialog = glade_xml_get_widget (xml, "Initial Password Dialog");
 
   if (parent)
-    gnome_dialog_set_parent (GNOME_DIALOG (dialog), GTK_WINDOW (parent));
+    gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (parent));
 
   heading_label  = glade_xml_get_widget (xml, "heading_label");
   password_entry = glade_xml_get_widget (xml, "password_entry");
   confirm_entry = glade_xml_get_widget (xml, "confirm_entry");
   g_assert(heading_label && password_entry && confirm_entry);
 
-  gnome_dialog_set_default (GNOME_DIALOG (dialog), 0);
+  gtk_dialog_set_default_response (GTK_DIALOG (dialog), 1);
 
-  gnome_dialog_editable_enters (GNOME_DIALOG (dialog),
-                                GTK_EDITABLE (password_entry));
-  gnome_dialog_editable_enters (GNOME_DIALOG (dialog),
-                                GTK_EDITABLE (confirm_entry));
+  gtk_entry_set_activates_default (GTK_ENTRY (password_entry), FALSE);
+  gtk_entry_set_activates_default (GTK_ENTRY (confirm_entry), TRUE);
 
   if (windowtitle)
     gtk_window_set_title (GTK_WINDOW (dialog), windowtitle);
@@ -134,38 +124,27 @@ gnc_hbci_get_initial_password (GtkWidget *parent,
   if (heading)
     gtk_label_set_text (GTK_LABEL (heading_label), heading);
 
-  gtk_widget_grab_focus (password_entry);
-
-  /* Hide on close instead of destroy since we still need the values
-     from the boxes. */
-  gnome_dialog_close_hides (GNOME_DIALOG (dialog), TRUE);
-
   while (TRUE) {
-    result = gnome_dialog_run_and_close (GNOME_DIALOG (dialog));
+    result = gtk_dialog_run (GTK_DIALOG (dialog));
     
-    if (result == 0)
+    if (result == 1) /* the hand-assigned response value */
       {
-	char *pw, *confirm;
-	pw = gtk_editable_get_chars (GTK_EDITABLE (password_entry), 0, -1);
-	confirm = gtk_editable_get_chars (GTK_EDITABLE (confirm_entry), 
-					  0, -1);
+	const char *pw = gtk_entry_get_text (GTK_ENTRY (password_entry));
+	const char *confirm = gtk_entry_get_text (GTK_ENTRY (confirm_entry));
 	if (strcmp (pw, confirm) == 0) {
-	  *password = pw;
-	  g_free (confirm);
+	  *password = g_strdup(pw);
 	  gtk_widget_destroy (GTK_WIDGET (dialog));
 	  return TRUE;
 	}
-	g_free (pw);
-	g_free (confirm);
       }
     else
       break;
 
     /* strings didn't match */
-    if (gnc_ok_cancel_dialog_parented (parent, GNC_VERIFY_OK,
-			      _("The two passwords didn't match. \n"
+    if (gnc_ok_cancel_dialog (parent, GTK_RESPONSE_OK,
+			      _("The two passwords didn't match. "
 				"Please try again."))
-	== GNC_VERIFY_CANCEL)
+	!= GTK_RESPONSE_OK)
       break;
   }
   *password = NULL;
