@@ -16,14 +16,13 @@
  * along with this program; if not, contact:                        *
  *                                                                  *
  * Free Software Foundation           Voice:  +1-617-542-5942       *
- * 59 Temple Place - Suite 330        Fax:    +1-617-542-2652       *
- * Boston, MA  02111-1307,  USA       gnu@gnu.org                   *
+ * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
+ * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
 \********************************************************************/
 
 #ifndef DRUID_HBCI_UTILS_H
 #define DRUID_HBCI_UTILS_H
 
-#include <gnome.h>
 #include <aqbanking/banking.h>
 #include "hbci-interaction.h"
 #include "gnc-hbci-utils.h"
@@ -52,7 +51,7 @@ gboolean
 gnc_verify_exist_or_new_file (GtkWidget *parent, const char *filename);
 
 gboolean
-gnc_test_dir_exist_error (GtkWidget *parent, const char *filename);
+gnc_test_dir_exist_error (GtkWindow *parent, const char *filename);
 
 
 #endif
