@@ -16,15 +16,15 @@
  * along with this program; if not, contact:                        *
  *                                                                  *
  * Free Software Foundation           Voice:  +1-617-542-5942       *
- * 59 Temple Place - Suite 330        Fax:    +1-617-542-2652       *
- * Boston, MA  02111-1307,  USA       gnu@gnu.org                   *
+ * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
+ * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
 \********************************************************************/
 
 #ifndef GNC_HBCI_KVP_H
 #define GNC_HBCI_KVP_H
 
 #include <glib.h>
-#include "kvp_frame.h"
+#include "qof.h"
 #include "Account.h"
 #include "gnc-book.h"
 
@@ -93,11 +93,13 @@ void gnc_hbci_set_book_account_list (GNCBook *b, GList *account_list);
 
 /* lowlevel */
 
-/* internal getter for kvp frame in book */
-kvp_frame *gnc_hbci_get_book_kvp (GNCBook *b);
+/* internal getter for kvp frame in book. The create argument says
+ *  to create the frame if it doesn't already exist. */
+kvp_frame *gnc_hbci_get_book_kvp (GNCBook *b, gboolean create);
 
-/* internal getter for kvp frame in Account */
-kvp_frame *gnc_hbci_get_account_kvp (Account *a);
+/* internal getter for kvp frame in Account. The create argument says
+ *  to create the frame if it doesn't already exist. */
+kvp_frame *gnc_hbci_get_account_kvp (Account *a, gboolean create);
 
 
 
