@@ -23,6 +23,7 @@
     @brief import-backend.c: Generic importer backend implementation (duplicate matching algorithm, action handling,  etc.)
     @author Copyright (C) 2002 Benoit Grgoire
     @author Christian Stimming
+    @author Copyright (c) 2006 David Hampton <hampton@employees.org>
 */
  
 #include "config.h"
@@ -32,6 +33,8 @@
 #include <stdlib.h> 
 #include <math.h>
 
+#include <errno.h>
+
 #include "gnc-gconf-utils.h"
 #include "import-backend.h"
 #include "import-utilities.h"
@@ -256,9 +259,9 @@ void gnc_import_TransInfo_delete (GNCImportTransInfo *info)
   }
 }
 
-GdkPixmap* gen_probability_pixmap(gint score_original, GNCImportSettings *settings, GtkWidget * widget)
+GdkPixbuf* gen_probability_pixbuf(gint score_original, GNCImportSettings *settings, GtkWidget * widget)
 {
-  GdkPixmap* retval = NULL;
+  GdkPixbuf* retval = NULL;
   gint i, j;
   gint score;
   const gint height = 15;
@@ -339,11 +342,7 @@ GdkPixmap* gen_probability_pixmap(gint score_original, GNCImportSettings *settin
 	}
     }  
   
-  retval =  gdk_pixmap_colormap_create_from_xpm_d    (NULL,
-						      gtk_widget_get_colormap(widget),
-						      NULL,
-						      NULL,
-						      xpm);
+  retval =  gdk_pixbuf_new_from_xpm_data((const gchar **)xpm);
   for(i=0;i<=num_colors+height;i++)
     { 
       /*DEBUG("free_loop i=%d%s%s",i,": ",xpm[i]);*/
@@ -416,7 +415,7 @@ TransactionGetTokens(GNCImportTransInfo *info)
    */
   transtime = xaccTransGetDate(transaction);
   tm_struct = gmtime(&transtime);
-  if(!strftime(local_day_of_week, sizeof(local_day_of_week), "%A", tm_struct))
+  if(!qof_strftime(local_day_of_week, sizeof(local_day_of_week), "%A", tm_struct))
     {
       PERR("TransactionGetTokens: error, strftime failed\n");
     }
@@ -585,13 +584,13 @@ static void split_find_match (GNCImportTransInfo * trans_info,
       time_t match_time, download_time;
       int datediff_day;
       Transaction *new_trans = gnc_import_TransInfo_get_trans (trans_info);
+      Split *new_trans_fsplit = gnc_import_TransInfo_get_fsplit (trans_info);
     
       /* Matching heuristics */
     
       /* Amount heuristics */
       downloaded_split_amount = 
-	gnc_numeric_to_double
-	(xaccSplitGetAmount(gnc_import_TransInfo_get_fsplit (trans_info)));
+	gnc_numeric_to_double (xaccSplitGetAmount(new_trans_fsplit));
       /*DEBUG(" downloaded_split_amount=%f", downloaded_split_amount);*/
       match_split_amount = gnc_numeric_to_double(xaccSplitGetAmount(split));
       /*DEBUG(" match_split_amount=%f", match_split_amount);*/
@@ -599,7 +598,7 @@ static void split_find_match (GNCImportTransInfo * trans_info,
 	/* bug#347791: Doubly type shouldn't be compared for exact
 	   equality, so we're using fabs() instead. */
 	/*if (gnc_numeric_equal(xaccSplitGetAmount
-	  (gnc_import_TransInfo_get_fsplit (trans_info)),
+	  (new_trans_fsplit),
 	  xaccSplitGetAmount(split))) 
 	  -- gnc_numeric_equal is an expensive function call */
 	{
@@ -656,38 +655,56 @@ static void split_find_match (GNCImportTransInfo * trans_info,
 	     split anyway and skip the rest of the tests.) */
 	}
       
-      /* Check number heuristics */  
-      if(strlen(xaccTransGetNum(new_trans))!=0)
-	{     
-	  if((strcmp(xaccTransGetNum (new_trans),
-		     xaccTransGetNum(xaccSplitGetParent(split)))
-	      ==0))
-	    {	
-	      /*An exact match of the Check number gives a +4 */
-	      prob = prob+4;
-	      /*DEBUG("heuristics:  probability + 5 (Check number)");*/
-	    }
-	  else if(strlen(xaccTransGetNum(new_trans)) > 0 &&
-		  strlen(xaccTransGetNum(xaccSplitGetParent(split))) > 0)
-	    {
-	      /* If both number are not empty yet do not match, add a little extre penality */
-	      prob = prob-2;
-	    }
-	}
-      
+      /* Check number heuristics */
+      {
+	const char *new_trans_str = xaccTransGetNum(new_trans);
+	if (new_trans_str && strlen(new_trans_str) != 0) { 
+          long new_trans_number, split_number;
+          const gchar *split_str;
+          char *endptr;
+          gboolean conversion_ok = TRUE;
+          
+          /* To distinguish success/failure after strtol call */
+          errno = 0;
+          new_trans_number = strtol(new_trans_str, &endptr, 10);
+          /* Possible addressed problems: over/underflow, only non
+	     numbers on string and string empty */
+          if (errno || endptr == new_trans_str) 
+	    conversion_ok = FALSE;
+            
+          split_str = xaccTransGetNum (xaccSplitGetParent (split));
+          errno = 0;
+          split_number = strtol(split_str, &endptr, 10);
+          if (errno || endptr == split_str) 
+	    conversion_ok = FALSE;
+            
+          if ( (conversion_ok && (split_number == new_trans_number)) || 
+	       (safe_strcmp(new_trans_str, split_str) == 0) )
+            {  
+              /*An exact match of the Check number gives a +4 */
+              prob += 4;
+              /*DEBUG("heuristics:  probability + 4 (Check number)");*/
+            }
+          else if(strlen(new_trans_str) > 0 && strlen(split_str) > 0)
+            {
+              /* If both number are not empty yet do not match, add a
+		 little extra penality */
+              prob -= 2;
+            }
+        }
+      }
+
       /* Memo heuristics */  
-      if(strlen(xaccSplitGetMemo(gnc_import_TransInfo_get_fsplit (trans_info)))!=0)
-	{
-	  if((strcmp(xaccSplitGetMemo(gnc_import_TransInfo_get_fsplit (trans_info)),
-		     xaccSplitGetMemo(split))
-	      ==0))
+      {
+	const char *memo = xaccSplitGetMemo(new_trans_fsplit);
+	if (memo && strlen(memo) != 0) {
+	  if (safe_strcmp(memo, xaccSplitGetMemo(split)) == 0)
 	    {	
 	      /* An exact match of memo gives a +2 */
 	      prob = prob+2;
 	      /* DEBUG("heuristics:  probability + 2 (memo)"); */
 	    }
-	  else if((strncmp(xaccSplitGetMemo(gnc_import_TransInfo_get_fsplit (trans_info)),
-			   xaccSplitGetMemo(split),
+	  else if((strncmp(memo, xaccSplitGetMemo(split),
 			   strlen(xaccSplitGetMemo(split))/2)
 		   ==0))
 	    {
@@ -699,19 +716,21 @@ static void split_find_match (GNCImportTransInfo * trans_info,
 	      /*DEBUG("heuristics:  probability + 1 (memo)");	*/
 	    }
 	}
+      }
 
-      /* Description heuristics */  
-      if(strlen(xaccTransGetDescription(new_trans))!=0)
-	{
-	  if((strcmp(xaccTransGetDescription (new_trans),
-		     xaccTransGetDescription(xaccSplitGetParent(split)))
-	      ==0))
+      /* Description heuristics */
+      {
+	const char *descr = xaccTransGetDescription(new_trans);
+	if (descr && strlen(descr) != 0) {
+	  if (safe_strcmp(descr,
+			  xaccTransGetDescription(xaccSplitGetParent(split)))
+	      ==0)
 	    {	
 	      /*An exact match of Description gives a +2 */
 	      prob = prob+2;
 	      /*DEBUG("heuristics:  probability + 2 (description)");*/
 	    }
-	  else if((strncmp(xaccTransGetDescription (new_trans),
+	  else if((strncmp(descr,
 			   xaccTransGetDescription (xaccSplitGetParent(split)),
 			   strlen(xaccTransGetDescription (new_trans))/2)
 		   ==0))
@@ -724,17 +743,18 @@ static void split_find_match (GNCImportTransInfo * trans_info,
 	      /*DEBUG("heuristics:  probability + 1 (description)");	*/
 	    }
 	}
+      }
 
       /*Online id punishment*/
-      if ((gnc_import_get_trans_online_id(xaccSplitGetParent(split))!=NULL) &&
-	  (strlen(gnc_import_get_trans_online_id(xaccSplitGetParent(split)))>0))
-	{
+/*       if ((gnc_import_get_trans_online_id(xaccSplitGetParent(split))!=NULL) && */
+/* 	  (strlen(gnc_import_get_trans_online_id(xaccSplitGetParent(split)))>0)) */
+/* 	{ */
 	  /* If the pref is to show match even with online ID's,
 	     puninsh the transaction with online id */
 	  
 	  /* DISABLED, it's the wrong solution to the problem. benoitg, 24/2/2003 */
 	  /*prob = prob-3;*/
-	}
+/* 	} */
       
       /* Is the probability high enough? Otherwise do nothing and return. */
       if(prob < display_threshold)
@@ -822,23 +842,14 @@ void gnc_import_find_split_matches(GNCImportTransInfo *trans_info,
 /***********************************************************************
  */
 
-/** /brief -- Processes every selected match
+/** /brief -- Processes one match
    according to its selected action.  */
-void
-gnc_import_process_trans_clist (GtkCList *clist, 
-				GncImportMatchMap *matchmap)
+gboolean
+gnc_import_process_trans_item (GncImportMatchMap *matchmap,
+			       GNCImportTransInfo *trans_info)
 {
-  GNCImportTransInfo * trans_info;
-  gint row_number = 0, i = 0;
-  g_assert (clist);
-  
   /* DEBUG("Begin"); */
-  gtk_clist_freeze (clist);
-  trans_info = 
-    (GNCImportTransInfo *) gtk_clist_get_row_data(clist, 0);
-  
-  for(i = 1; trans_info != NULL; i++)
-    {
+
       g_assert (trans_info);
       /*DEBUG("Iteration %d, action %d, split %s", i, 
 	trans_info->action,
@@ -847,7 +858,7 @@ gnc_import_process_trans_clist (GtkCList *clist,
       switch (gnc_import_TransInfo_get_action (trans_info))
 	{
 	case GNCImport_SKIP:
-	  break;
+	  return FALSE;
 	case GNCImport_ADD:
 	  /* Transaction gets imported. */
 
@@ -857,7 +868,7 @@ gnc_import_process_trans_clist (GtkCList *clist,
 	    /* Create the 'other' split. */
 	    Split *split = 
 	      xaccMallocSplit
-	      (xaccAccountGetBook
+	      (gnc_account_get_book
 	       (gnc_import_TransInfo_get_destacc (trans_info)));
 	    xaccTransAppendSplit
 	      (gnc_import_TransInfo_get_trans (trans_info), split);
@@ -889,7 +900,7 @@ gnc_import_process_trans_clist (GtkCList *clist,
 	  /* Done editing. */
 	  xaccTransCommitEdit 
 	    (gnc_import_TransInfo_get_trans (trans_info));
-	  break;
+	  return TRUE;
 	case GNCImport_CLEAR: {
 	  GNCImportMatchInfo *selected_match =
 	    gnc_import_TransInfo_get_selected_match (trans_info);
@@ -946,31 +957,15 @@ gnc_import_process_trans_clist (GtkCList *clist,
 	      trans_info->trans = NULL;
 	    }
 	  }
-	  break;
+	  return TRUE;
 	case GNCImport_EDIT:
 	    PERR("EDIT action is UNSUPPORTED!");
 	  break;
 	default:
 	  DEBUG("Invalid GNCImportAction for this imported transaction.");
 	}
-
-      /* For all actions except SKIP delete this transaction now. */
-      if(trans_info->action != GNCImport_SKIP) {
-	row_number = gtk_clist_find_row_from_data(clist, trans_info);
-	gtk_clist_remove (clist, row_number);
-	/* decrement the iteration counter since we've just removed
-	   one row. */
-	i--;
-      }
-
-      /* Get next trans_info, NULL if finished */
-      trans_info =
-	(GNCImportTransInfo *) gtk_clist_get_row_data(clist, i);
-    }
-  
   /*DEBUG("End");*/
-  gtk_clist_thaw (clist);
-  /*DEBUG("Thawed.")*/
+  return FALSE;
 }
 
 /********************************************************************\
