@@ -27,10 +27,10 @@
     "strings" to Gnucash accounts in a generic manner.
     @author Copyright (C) 2002,2003 Derek Atkins <derek@ihtfp.com>
  */
+#include "config.h"
 #include <string.h>
 #include <glib.h>
 #include "import-match-map.h"
-#include "Group.h"
 #include "gnc-ui-util.h"
 #include "gnc-engine.h"
 
@@ -65,7 +65,7 @@ gnc_imap_create_from_frame (kvp_frame *frame, Account *acc, GNCBook *book)
    * marking dirtiness
    */
   if (acc)
-    book = xaccAccountGetBook (acc);
+    book = gnc_account_get_book (acc);
   imap->acc = acc;
   imap->book = book;
   
@@ -434,15 +434,17 @@ Account* gnc_imap_find_account_bayes(GncImportMatchMap *imap, GList *tokens)
   g_hash_table_destroy(running_probabilities);
   g_hash_table_destroy(final_probabilities);
 
-  PINFO("highest P('%s') = '%d'", account_i.account_name, account_i.probability);
+  PINFO("highest P('%s') = '%d'",
+        account_i.account_name ? account_i.account_name: "(null)",
+        account_i.probability);
 
   /* has this probability met our threshold? */
   if(account_i.probability >= threshold)
     {
       PINFO("found match");
       LEAVE(" ");
-      return xaccGetAccountFromFullName(gnc_book_get_group(imap->book),
-					account_i.account_name);
+      return gnc_account_lookup_by_full_name(gnc_book_get_root_account(imap->book),
+                                             account_i.account_name);
     }
 
   PINFO("no match");
@@ -483,7 +485,7 @@ void gnc_imap_add_account_bayes(GncImportMatchMap *imap, GList *tokens, Account
 	 string, which doesn't work in the kvp loopkup later. So we
 	 skip this case here. */
       if (!current_token->data || (*((char*)current_token->data) == '\0'))
-	continue;
+           continue;
 
       /* start off with no tokens for this account */
       token_count = 0;
