@@ -13,8 +13,8 @@
  * along with this program; if not, contact:                        *
  *                                                                  *
  * Free Software Foundation           Voice:  +1-617-542-5942       *
- * 59 Temple Place - Suite 330        Fax:    +1-617-542-2652       *
- * Boston, MA  02111-1307,  USA       gnu@gnu.org                   *
+ * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
+ * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
 \********************************************************************/
 /** @addtogroup Import_Export
     @{ */
@@ -24,38 +24,20 @@
    transaction matching (for both the gui and the backend)
    @author Copyright (C) 2002 Benoit Grgoire
 */
-#define _GNU_SOURCE
-
 #include "config.h"
 
 #include <glib.h>
-#include "dialog-utils.h"
-#include "global-options.h"
+
 #include "import-settings.h"
+#include "gnc-gconf-utils.h"
 
 /********************************************************************\
  * Default values for user prefs (or values for unimplemented prefs.*
  * If you modify the value of any of these, you must do the same in *
  * generic-import.scm                                               *
 \********************************************************************/
-#define MATCHER_PREF_PAGE "Online Banking & Importing"
+#define GCONF_SECTION "dialogs/import/generic_matcher"
 
-/** Transaction who's best match probability is equal or higher than
-   this will reconcile their best match by default */
-#define DEFAULT_CLEAR_THRESHOLD 6
-/** Transaction who's best match probability is below or equal to 
-   this will be added as new by default */
-#define DEFAULT_ADD_THRESHOLD 3
-/** Transaction's match probability must be at least this much to be 
-   displayed in the match list.  Dont set this to 0 except for 
-   debugging purposes, otherwise all transactions of every accounts 
-   will be shown in the list */
-#define DEFAULT_DISPLAY_THRESHOLD 1
-
-#define DEFAULT_ATM_FEE_THRESHOLD 2.00
-
-static const int DEFAULT_ACTION_SKIP_ENABLED = TRUE;
-static const int DEFAULT_ACTION_EDIT_ENABLED = FALSE;
 static const int DEFAULT_ACTION_ADD_ENABLED = TRUE;
 static const int DEFAULT_ACTION_CLEAR_ENABLED = TRUE;
 
@@ -64,7 +46,7 @@ static const int DEFAULT_ACTION_CLEAR_ENABLED = TRUE;
 \********************************************************************/
 
 struct _genimportsettings {
-  
+
   gboolean action_skip_enabled;
   gboolean action_edit_enabled;
   gboolean action_add_enabled;
@@ -101,28 +83,20 @@ gnc_import_Settings_new (void)
 
   
   settings->action_skip_enabled = 
-    gnc_lookup_boolean_option(MATCHER_PREF_PAGE,
-			      "Enable SKIP transaction action",
-			      DEFAULT_ACTION_SKIP_ENABLED);
+    gnc_gconf_get_bool(GCONF_SECTION, "enable_skip", NULL);
   settings->action_edit_enabled =
-    gnc_lookup_boolean_option(MATCHER_PREF_PAGE,
-			      "Enable EDIT match action",
-			      DEFAULT_ACTION_EDIT_ENABLED);
+    gnc_gconf_get_bool(GCONF_SECTION, "enable_edit", NULL);
   settings->action_add_enabled=DEFAULT_ACTION_ADD_ENABLED;
   settings->action_clear_enabled=DEFAULT_ACTION_CLEAR_ENABLED;
-  settings->clear_threshold=gnc_lookup_number_option(MATCHER_PREF_PAGE,
-						     "Auto-CLEAR threshold",
-						     DEFAULT_CLEAR_THRESHOLD);
-  settings->add_threshold=gnc_lookup_number_option(MATCHER_PREF_PAGE,
-						   "Auto-ADD threshold",
-						   DEFAULT_ADD_THRESHOLD);
+  settings->clear_threshold=
+    gnc_gconf_get_float(GCONF_SECTION, "auto_clear_threshold", NULL);
+  settings->add_threshold=
+    gnc_gconf_get_float(GCONF_SECTION, "auto_add_threshold", NULL);
   settings->display_threshold =
-    gnc_lookup_number_option(MATCHER_PREF_PAGE,"Match display threshold",
-			     DEFAULT_DISPLAY_THRESHOLD);
+    gnc_gconf_get_float(GCONF_SECTION, "match_threshold", NULL);
 
   settings->fuzzy_amount =
-    gnc_lookup_number_option(MATCHER_PREF_PAGE,"Commercial ATM fees threshold",
-			     DEFAULT_ATM_FEE_THRESHOLD);
+    gnc_gconf_get_float(GCONF_SECTION, "atm_fee_threshold", NULL);
 
   settings->match_date_hardlimit = 42; /* 6 weeks */
   return settings;
