@@ -1,12 +1,12 @@
 /*********************************************************************
  * gncmod-qif-import.c
  * module definition/initialization for old QIF importer (deprecated)
- * 
- * Copyright (c) 2001 Linux Developers Group, Inc. 
+ *
+ * Copyright (c) 2001 Linux Developers Group, Inc.
  *********************************************************************/
 
 #include "config.h"
-#include <glib.h>
+#include <gmodule.h>
 #include <libguile.h>
 
 #include "gnc-module.h"
@@ -16,47 +16,43 @@
 
 #include "gnc-plugin-qif-import.h"
 
+GNC_MODULE_API_DECL(libgncmod_qif_import)
+
 /* version of the gnc module system interface we require */
-int libgncmod_qif_import_LTX_gnc_module_system_interface = 0;
+int libgncmod_qif_import_gnc_module_system_interface = 0;
 
 /* module versioning uses libtool semantics. */
-int libgncmod_qif_import_LTX_gnc_module_current  = 0;
-int libgncmod_qif_import_LTX_gnc_module_revision = 0;
-int libgncmod_qif_import_LTX_gnc_module_age      = 0;
-
-/* forward references */
-char *libgncmod_qif_import_LTX_gnc_module_path(void);
-char *libgncmod_qif_import_LTX_gnc_module_description(void);
-int libgncmod_qif_import_LTX_gnc_module_init(int refcount);
-int libgncmod_qif_import_LTX_gnc_module_end(int refcount);
+int libgncmod_qif_import_gnc_module_current  = 0;
+int libgncmod_qif_import_gnc_module_revision = 0;
+int libgncmod_qif_import_gnc_module_age      = 0;
 
 
 char *
-libgncmod_qif_import_LTX_gnc_module_path(void) 
+libgncmod_qif_import_gnc_module_path(void)
 {
   return g_strdup("gnucash/import-export/qif-import");
 }
 
-char * 
-libgncmod_qif_import_LTX_gnc_module_description(void) 
+char *
+libgncmod_qif_import_gnc_module_description(void)
 {
   return g_strdup("Gnome GUI and Scheme code for QIF importer");
 }
 
 int
-libgncmod_qif_import_LTX_gnc_module_init(int refcount) 
+libgncmod_qif_import_gnc_module_init(int refcount)
 {
-  if(!gnc_module_load("gnucash/engine", 0)) 
+  if(!gnc_module_load("gnucash/engine", 0))
   {
     return FALSE;
   }
 
-  if(!gnc_module_load("gnucash/app-utils", 0)) 
+  if(!gnc_module_load("gnucash/app-utils", 0))
   {
     return FALSE;
   }
 
-  if(!gnc_module_load("gnucash/gnome-utils", 0)) 
+  if(!gnc_module_load("gnucash/gnome-utils", 0))
   {
     return FALSE;
   }
@@ -78,7 +74,7 @@ libgncmod_qif_import_LTX_gnc_module_init(int refcount)
 }
 
 int
-libgncmod_qif_import_LTX_gnc_module_end(int refcount) 
+libgncmod_qif_import_gnc_module_end(int refcount)
 {
   return TRUE;
 }
