@@ -302,14 +302,15 @@ gnc_split_register_load (SplitRegister *reg, GList * slist,
     find_trans = blank_trans;
     find_split = NULL;
     find_trans_split = blank_split;
+    find_class = CURSOR_CLASS_SPLIT;
   }
   else
   {
     find_trans = info->cursor_hint_trans;
     find_split = info->cursor_hint_split;
     find_trans_split = info->cursor_hint_trans_split;
+    find_class = info->cursor_hint_cursor_class;
   }
-  find_class = info->cursor_hint_cursor_class;
 
   save_loc = table->current_cursor_loc;
 
@@ -362,26 +363,30 @@ gnc_split_register_load (SplitRegister *reg, GList * slist,
       }
     }
 
-    /* set the completion character for the xfer cells */
-    gnc_combo_cell_set_complete_char(
-        (ComboCell *) gnc_table_layout_get_cell(table->layout, MXFRM_CELL),
-        gnc_get_account_separator());
-  
-    gnc_combo_cell_set_complete_char(
-        (ComboCell *) gnc_table_layout_get_cell(table->layout, XFRM_CELL),
-        gnc_get_account_separator());
-  
-    /* set the confirmation callback for the reconcile cell */
-    gnc_recn_cell_set_confirm_cb(
-        (RecnCell *) gnc_table_layout_get_cell(table->layout, RECN_CELL),
-        gnc_split_register_recn_cell_confirm, reg);
-  
     /* load up account names into the transfer combobox menus */
     gnc_split_register_load_xfer_cells (reg, default_account);
     gnc_split_register_load_recn_cells (reg);
     gnc_split_register_load_type_cells (reg);
   }
 
+  if (info->separator_changed) {
+    info->separator_changed = FALSE;
+
+    /* set the completion character for the xfer cells */
+    gnc_combo_cell_set_complete_char(
+      (ComboCell *) gnc_table_layout_get_cell(table->layout, MXFRM_CELL),
+      gnc_get_account_separator());
+
+    gnc_combo_cell_set_complete_char(
+      (ComboCell *) gnc_table_layout_get_cell(table->layout, XFRM_CELL),
+      gnc_get_account_separator());
+
+    /* set the confirmation callback for the reconcile cell */
+    gnc_recn_cell_set_confirm_cb(
+      (RecnCell *) gnc_table_layout_get_cell(table->layout, RECN_CELL),
+      gnc_split_register_recn_cell_confirm, reg);
+  }
+
   table->model->dividing_row = -1;
 
   // Ensure that the transaction and splits being edited are in the split
