@@ -1,13 +1,13 @@
 /*********************************************************************
  * gncmod-register-gnome.c
  * module definition/initialization for Gnome parts of register
- * 
- * Copyright (c) 2001 Linux Developers Group, Inc. 
+ *
+ * Copyright (c) 2001 Linux Developers Group, Inc.
  *********************************************************************/
 
 #include "config.h"
 
-#include <glib.h>
+#include <gmodule.h>
 
 #include "combocell.h"
 #include "datecell.h"
@@ -19,32 +19,29 @@
 #include "register-common.h"
 #include "table-gnome.h"
 
+GNC_MODULE_API_DECL(libgncmod_register_gnome)
+
 /* version of the gnc module system interface we require */
-int libgncmod_register_gnome_LTX_gnc_module_system_interface = 0;
+int libgncmod_register_gnome_gnc_module_system_interface = 0;
 
 /* module versioning uses libtool semantics. */
-int libgncmod_register_gnome_LTX_gnc_module_current  = 0;
-int libgncmod_register_gnome_LTX_gnc_module_revision = 0;
-int libgncmod_register_gnome_LTX_gnc_module_age      = 0;
-
-/* forward references */
-char *libgncmod_register_gnome_LTX_gnc_module_path(void);
-char *libgncmod_register_gnome_LTX_gnc_module_description(void);
-int libgncmod_register_gnome_LTX_gnc_module_init(int refcount);
+int libgncmod_register_gnome_gnc_module_current  = 0;
+int libgncmod_register_gnome_gnc_module_revision = 0;
+int libgncmod_register_gnome_gnc_module_age      = 0;
 
 
 char *
-libgncmod_register_gnome_LTX_gnc_module_path(void) {
+libgncmod_register_gnome_gnc_module_path(void) {
   return g_strdup("gnucash/register/register-gnome");
 }
 
-char * 
-libgncmod_register_gnome_LTX_gnc_module_description(void) {
+char *
+libgncmod_register_gnome_gnc_module_description(void) {
   return g_strdup("Gnome GUI for ledger-like table displays");
 }
 
 int
-libgncmod_register_gnome_LTX_gnc_module_init(int refcount) {
+libgncmod_register_gnome_gnc_module_init(int refcount) {
   if(!gnc_module_load("gnucash/register/register-core", 0)) {
     return FALSE;
   }
@@ -53,7 +50,7 @@ libgncmod_register_gnome_LTX_gnc_module_init(int refcount) {
     return FALSE;
   }
 
-  if (refcount == 0) 
+  if (refcount == 0)
   {
     gnc_register_add_cell_type (COMBO_CELL_TYPE_NAME, gnc_combo_cell_new);
 
