@@ -565,6 +565,94 @@
 				 (assoc account-comm sumlist)
 				 tmp)))
 	       
+             (cond ((gnc-numeric-zero-p share-amount)
+                    ;; Without shares this is not a buy or sell; ignore it.
+                    #f)
+
+                   ((not comm-list)
+	            ;; entry doesn't exist in comm-list
+		    ;; create sub-alist from scratch
+		    (let ((pair (list transaction-comm
+				      (cons (gnc:make-numeric-collector)
+					    (gnc:make-numeric-collector)))))
+		      ((caadr pair) 'add value-amount)
+		      ((cdadr pair) 'add share-amount)
+		      (set! comm-list (list account-comm (list pair)))
+		      ;; and add the new sub-alist to sumlist.
+		      (set! sumlist (cons comm-list sumlist))))
+
+                   (else
+		    (let* 
+		          ;; Put the amounts in the right place.
+		          ((foreignlist 
+		            (if (gnc-commodity-equiv transaction-comm
+						      (car comm-list))
+			        (list account-comm 
+				      share-amount value-amount)
+			        (list transaction-comm 
+				      value-amount share-amount)))
+		           ;; second commodity already existing in comm-list?
+		           (pair (assoc (car foreignlist) (cadr comm-list))))
+		      ;; if not, create a new entry in comm-list.
+		      (if (not pair)
+		          (begin
+			    (set! 
+			     pair (list (car foreignlist)
+				        (cons (gnc:make-numeric-collector) 
+					      (gnc:make-numeric-collector))))
+			    (set! 
+			     comm-list (list (car comm-list) 
+					     (cons pair (cadr comm-list))))
+			    (set! 
+			     sumlist (cons comm-list 
+					   (alist-delete 
+					    (car comm-list) sumlist)))))
+		      ;; And add the balances to the comm-list entry.
+		      ((caadr pair) 'add (cadr foreignlist))
+		      ((cdadr pair) 'add (caddr foreignlist)))))))
+	 (gnc:get-all-commodity-splits curr-accounts end-date)))
+  
+    (gnc:resolve-unknown-comm sumlist report-commodity)))
+
+;; Calculate the volume-weighted average cost of all commodities,
+;; priced in the 'report-commodity'. Uses all transactions up until
+;; the 'end-date'. Returns an alist, see sumlist.
+(define (gnc:get-exchange-cost-totals report-commodity end-date)
+  (let ((curr-accounts 
+	 ;;(filter gnc:account-has-shares? ))
+	 ;; -- use all accounts, not only share accounts, since gnucash-1.7
+	 (gnc-account-get-descendants-sorted (gnc-get-current-root-account)))
+	;; sumlist: a multilevel alist. Each element has a commodity
+	;; as key, and another alist as a value. The value-alist's
+	;; elements consist of a commodity as a key, and a pair of two
+	;; value-collectors as value, e.g. with only one (the report-)
+	;; commodity DEM in the outer alist: ( {DEM ( [USD (400 .
+	;; 1000)] [FRF (300 . 100)] ) } ) where DEM,USD,FRF are
+	;; <gnc:commodity> and the numbers are a numeric-collector
+	;; which in turn store a <gnc:numeric>. In the example, USD
+	;; 400 were bought for an amount of DEM 1000, FRF 300 were
+	;; bought for DEM 100. The reason for the outer alist is that
+	;; there might be commodity transactions which do not involve
+	;; the report-commodity, but which can still be calculated
+	;; after *all* transactions are processed.
+	(sumlist (list (list report-commodity '()))))
+
+    (if (not (null? curr-accounts))
+	;; Go through all splits and add up all value-amounts
+	;; and share-amounts
+	(for-each 
+	 (lambda (a)
+	   (let* ((transaction-comm (xaccTransGetCurrency
+				     (xaccSplitGetParent a)))
+		  (account-comm (xaccAccountGetCommodity
+				 (xaccSplitGetAccount a)))
+		  (share-amount (xaccSplitGetAmount a))
+		  (value-amount (xaccSplitGetValue a))
+		  (tmp (assoc transaction-comm sumlist))
+		  (comm-list (if (not tmp) 
+				 (assoc account-comm sumlist)
+				 tmp)))
+	       
 	     ;; entry exists already in comm-list?
 	     (if (not comm-list)
 		 ;; no, create sub-alist from scratch
@@ -626,6 +714,20 @@
 			     (logior (GNC-DENOM-SIGFIGS 8) GNC-RND-ROUND)))))
    (gnc:get-exchange-totals report-commodity end-date)))
 
+(define (gnc:make-exchange-cost-alist report-commodity end-date)
+  ;; This returns the alist with the actual exchange rates, i.e. the
+  ;; total balances from get-exchange-totals are divided by each
+  ;; other.
+  (map 
+   (lambda (e)
+     (list (car e) 
+	   (gnc-numeric-abs
+	    (gnc-numeric-div ((cdadr e) 'total #f)
+			     ((caadr e) 'total #f)
+			     GNC-DENOM-AUTO 
+			     (logior (GNC-DENOM-SIGFIGS 8) GNC-RND-ROUND)))))
+   (gnc:get-exchange-cost-totals report-commodity end-date)))
+
 
 
 
@@ -673,23 +775,24 @@
 (define (gnc:make-exchange-function exchange-alist)
   (let ((exchangelist exchange-alist))
     (lambda (foreign domestic)
-      (begin
-	(gnc:debug "foreign: " foreign)
-	(gnc:debug "domestic: " domestic)
-	(if foreign
-	    (or (gnc:exchange-by-euro foreign domestic #f)
-		(gnc:exchange-if-same foreign domestic)
-		(gnc:make-gnc-monetary 
-		 domestic
-		 (let ((pair (assoc (gnc:gnc-monetary-commodity foreign) 
-				    exchangelist)))
-		   (if (not pair)
-		       (gnc-numeric-zero)
-		       (gnc-numeric-mul (gnc:gnc-monetary-amount foreign)
-					(cadr pair)
-					(gnc-commodity-get-fraction domestic)
-					GNC-RND-ROUND)))))
-	  #f)))))
+      (gnc:debug "foreign: " foreign)
+      (gnc:debug "domestic: " domestic)
+      (if foreign
+          (or (gnc:exchange-by-euro foreign domestic #f)
+              (gnc:exchange-if-same foreign domestic)
+              (gnc:make-gnc-monetary
+               domestic
+               (let ((pair (assoc (gnc:gnc-monetary-commodity foreign)
+                                  exchangelist))
+                     (foreign-amount (gnc:gnc-monetary-amount foreign)))
+                 (if (or (not pair)
+                         (gnc-numeric-zero-p foreign-amount))
+                     (gnc-numeric-zero)
+                     (gnc-numeric-mul foreign-amount
+                                      (cadr pair)
+                                      (gnc-commodity-get-fraction domestic)
+                                      GNC-RND-ROUND)))))
+          #f))))
 
 ;; Helper for the gnc:exchange-by-pricalist* below. Exchange the
 ;; <gnc:monetary> 'foreign' into the <gnc:commodity*> 'domestic' by
@@ -821,6 +924,9 @@
 (define (gnc:case-exchange-fn 
 	 source-option report-currency to-date-tp)
   (case source-option
+    ((average-cost) (gnc:make-exchange-function 
+                     (gnc:make-exchange-cost-alist
+                      report-currency to-date-tp)))
     ((weighted-average) (gnc:make-exchange-function 
 			(gnc:make-exchange-alist 
 			 report-currency to-date-tp)))
@@ -828,8 +934,19 @@
     ((pricedb-nearest) (lambda (foreign domestic)
 			(gnc:exchange-by-pricedb-nearest
 			 foreign domestic to-date-tp)))
-    (else (gnc:warn "gnc:case-exchange-fn: bad price-source value: " 
-                    source-option))))
+    (else 
+     (begin
+       ;; FIX-ME 
+       ;; this is a hack to prevent report crashing if a report
+       ;; implements source-options that aren't fully implemented. We
+       ;; return a reasonably sane fallback function: nearest.
+       ;;
+       ;; known to be missing: pricedb-latest-before
+       (gnc:warn "gnc:case-exchange-fn: bad price-source value: " 
+                    source-option " using pricedb-nearest.")
+       (lambda (foreign domestic)
+	 (gnc:exchange-by-pricedb-nearest
+	  foreign domestic to-date-tp))))))
 
 ;; Return a ready-to-use function. Which one to use is determined by
 ;; the value of 'source-option', whose possible values are set in
@@ -858,8 +975,14 @@
     ((pricedb-latest) (lambda (foreign domestic date)
 		       (gnc:exchange-by-pricedb-latest foreign domestic)))
     ((pricedb-nearest) gnc:exchange-by-pricedb-nearest)
-    (else (gnc:warn "gnc:case-exchange-time-fn: bad price-source value: " 
-                    source-option))))
+    (else 
+     (begin
+       (gnc:warn "gnc:case-exchange-time-fn: bad price-source value: " 
+                    source-option ". Using pricedb-nearest.")
+       ;; FIX-ME another hack to prevent report crashing when an
+       ;; unimplemented source-option comes through
+       gnc:exchange-by-pricedb-nearest
+       ))))
 
 
 
