@@ -33,7 +33,9 @@
 (export gnc:pricealist-lookup-nearest-in-time)
 (export gnc:resolve-unknown-comm)
 (export gnc:get-exchange-totals)
+(export gnc:get-exchange-cost-totals)
 (export gnc:make-exchange-alist)
+(export gnc:make-exchange-cost-alist)
 (export gnc:exchange-by-euro)
 (export gnc:exchange-if-same)
 (export gnc:make-exchange-function)
@@ -575,6 +577,8 @@
 (export gnc-commodity-collector-commodity-count)
 (export gnc:account-get-balance-at-date)
 (export gnc:account-get-comm-balance-at-date)
+(export gnc:account-get-comm-value-interval)
+(export gnc:account-get-comm-value-at-date)
 (export gnc:accounts-get-balance-helper)
 (export gnc:accounts-get-comm-total-profit)
 (export gnc:accounts-get-comm-total-income)
