@@ -183,13 +183,19 @@
            (gnc:get-html-style-sheets)))))
 
     (if (procedure? generator)
-        (let ((options (generator)))
+        (let ((options (gnc:backtrace-if-exception generator)))
+          (if (not options)
+              (begin
+                (gnc:warn "BUG DETECTED: Scheme exception raised in "
+                          "report options generator procedure named "
+                          (procedure-name generator))
+                (set! options (gnc:new-options))))
           (gnc:register-option options stylesheet)
           (gnc:register-option options namer)
           options)
         (let ((options (gnc:new-options)))
           (gnc:register-option options stylesheet)
-          (gnc:register-option options names)
+          (gnc:register-option options namer)
           options))))
 
 ;; A <report> represents an instantiation of a particular report type.
@@ -250,9 +256,9 @@
 
 ;; gnc:make-report instantiates a report from a report-template.
 ;; The actual report is stored away in a hash-table -- only the id is returned.
-(define (gnc:make-report template-name . rest)
+(define (gnc:make-report template-id . rest)
   (let ((r ((record-constructor <report>) 
-            template-name ;; type
+            template-id ;; type
             #f            ;; id
             #f            ;; options
             #t            ;; dirty
@@ -260,7 +266,7 @@
             #f            ;; editor-widget
             #f            ;; ctext
             ))
-        (template (hash-ref *gnc:_report-templates_* template-name))
+        (template (hash-ref *gnc:_report-templates_* template-id))
         )
     (let ((options 
            (if (not (null? rest))
@@ -300,8 +306,8 @@
         #f))
   )
 
-(define (gnc:make-report-options template-name)
-  (let ((template (hash-ref *gnc:_report-templates_* template-name)))
+(define (gnc:make-report-options template-id)
+  (let ((template (hash-ref *gnc:_report-templates_* template-id)))
     (if template
         (gnc:report-template-new-options template)
         #f)))
